@@ -1,6 +1,6 @@
 package Gtk2::Ex::HyperTextBuffer;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 use strict;
 use Gtk2;
@@ -39,7 +39,7 @@ our %TAGS = (
 	underline => [underline => 'single'],
 	strike    => [strikethrough => 'true', foreground => 'grey'],
 	verbatim  => [family => 'monospace'], # wrap_mode => 'none'], # Bug withwrap_mode !?
-	Verbatim  => [family => 'monospace', wrap_mode => 'none', indent => 40],
+	Verbatim  => [family => 'monospace', wrap_mode => 'none', 'left-margin' => 40, indent => 0],
 	link      => [foreground => 'blue', underline => 'single'],
 	head1     => [weight => PANGO_WEIGHT_BOLD, scale => 1.15**4 ],
 	head2     => [weight => PANGO_WEIGHT_BOLD, scale => 1.15**3 ],
@@ -231,16 +231,39 @@ sub _insert_blocks {
 				$tag = $self->create_link_tag($bit ? undef : $$meta{to});
 			}
 			else { $tag = $self->get_tag_table->lookup($type) }
-			
+
 			if ($tag) {
-				#push @{$self->{edit_mode_tags}}, $tag;
-				@{$self->{edit_mode_tags}} = ($tag);
+				push @{$self->{edit_mode_tags}}, $tag;
+				#@{$self->{edit_mode_tags}} = ($tag);
 				$self->_insert_blocks(@$_[2 .. $#$_]); # recurs
-				#pop @{$self->{edit_mode_tags}};
-				@{$self->{edit_mode_tags}} = ();
+				pop @{$self->{edit_mode_tags}};
+				#@{$self->{edit_mode_tags}} = ();
 			}
 			elsif ($type eq 'Page' or $type eq 'Para') {
+				my $iv = $$meta{indent};
+				if ($iv) {
+					$self->{indent}=$iv;
+#warn "indent: $iv  / $type / " . @$_[2];
+					my $itag = $self->create_tag(
+						undef, ('left-margin' => 12 * $iv )
+					);
+					push @{$self->{edit_mode_tags}}, $itag;
+				}
 				$self->_insert_blocks(@$_[2 .. $#$_]); # recurs
+				if ($iv) {
+					pop @{$self->{edit_mode_tags}};
+				}
+			}
+			elsif ($type eq 'bullet') {
+				my $itag = $self->create_tag(
+					undef, (
+						'indent' => -10,
+						'left-margin' => $self->{indent} * 10 - 10
+					)
+				);
+				push @{$self->{edit_mode_tags}}, $itag;
+				$self->_insert_blocks(@$_[2 .. $#$_]); # recurs
+				pop @{$self->{edit_mode_tags}};
 			}
 			else { die "Unknown tag in parse tree: $type" }
 
