@@ -1,6 +1,6 @@
 package Gtk2::Ex::HyperTextView;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 use strict;
 use vars '%TAGS';
@@ -343,7 +343,8 @@ sub _smart_checkbox_toggle {
 		my $line = _get_line($buffer, $iter);
 		$line =~ /(\s*)/;
 		my $prefix = $1;
-		while ($line =~ /^($prefix\s*)\S/) {
+		while ($line =~ /^($prefix\s*\S|\s*$)/) {
+			# match linkes with same indent or only whitespace
 			$iter->backward_line or last;
 			$line = _get_line($buffer, $iter);
 		}
@@ -373,10 +374,10 @@ sub _check_sublist_items {
 	$iter->forward_line or return 0; # false at end of buffer
 	$line = _get_line($buffer, $iter);
 	my $done = 0; # did we find any items or not
-	while ($line =~ /^($prefix\s+)\S/) {
+	while ($line =~ /^($prefix\s+\S|\s*$)/) {
 		my $level = length $1;
-		if ($line =~ /^\s*\x{FFFC}/) {
-			$iter->forward_chars($level);
+		if ($line =~ /^(\s*)\x{FFFC}/) {
+			$iter->forward_chars(length $1);
 			if ($update) {
 				$iter = _toggle_checkbox($buffer, $iter, $state);
 			}
@@ -399,6 +400,7 @@ sub _get_line {
 	# FIXME belongs in TextBuffer
 	my ($buffer, $iter) = @_;
 	my $start = $buffer->get_iter_at_line($iter->get_line);
+	return '' if $start->ends_line; # empty line
 	my $end = $start->copy;
 	$end->forward_to_line_end;
 	return $buffer->get_slice($start, $end, 1);
