@@ -15,7 +15,7 @@ use Zim::Store;
 use Zim::History;
 use Zim::Page;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 our @ISA = qw/Zim::Events/;
 
@@ -35,13 +35,16 @@ Please report bugs to pardus\@cpan.org
 EOT
 our $AUTHORS = 'Jaap Karssenberg <pardus@cpan.org>';
 our $TRANSLATORS = q{
+Alexis Tamparopoulos (el)
 Andrew Kuzminov (ru)
 Andrés Rassol (es)
 Aron Xu (zh_CN)
 Balaam's Miracle (nl)
+Bjørn Olav Samdal (nb)
 BobMauchin (fr)
 Cheese Lee (zh_CN)
 Daniel Stoyanov (fr)
+Davide Truffa (it)
 Etienne Le Belléguy (fr)
 Frederik 'Freso' S. Olesen (da)
 Frits Salomons (nl)
@@ -55,8 +58,11 @@ Jean Demartini (fr)
 Jeppe Toustrup (da)
 João Santos (pt)
 Juhana Uuttu (fi)
+Junnan Wu (zh_CN)
 Jérôme Guelfucci (fr)
 Klaus Vormweg (de)
+Krzysztof Tataradziński (pl)
+Lucif (pl)
 M. Emin Akşehirli (tr)
 Mathijs (nl)
 Matteo Ferrabone (it)
@@ -80,9 +86,12 @@ Yaron (he)
 cyberik (zh_TW)
 dotancohen (he)
 fido_max (ru)
+kingu (nb)
 marisma (gl)
+nanker (da)
 rainofchaos (zh_CN)
 sanya (ru)
+warlock24 (pl)
 太和 (zh_CN)
 };
 our $WEBSITE = 'http://www.pardus.nl/projects/zim';
@@ -172,6 +181,9 @@ sub new {
 	$$self{config_file} = $self->get_notebook_config;
 	$$self{config_file}->read($$self{config}, 'Notebook')
 		if $$self{config_file};
+	print STDERR "WARNING: FS timestamp checks are disabled\n",
+	             "concurent editing will overwrite files without warning\n"
+		if $$self{config}{no_fs_check} ;
 
 	# Initialize version control
 	$$self{vcs} ||= $class->check_version_control($$self{dir})
@@ -204,7 +216,7 @@ sub new {
 		my $val = $self->{config}{Namespaces}{$ns};
 		my ($class, $arg) = split ',', $val, 2;
 		my %arg = map split('=',$_,2),
-		          map split(',',$_,2), $arg;
+		          map split(',',$_), $arg;
 		$self->add_child($ns => $class, %arg);
 	}
 
