@@ -6,7 +6,11 @@ use File::BaseDir qw/data_files/;
 use Zim::Template;
 use Zim::Formats;
 
-our $VERSION = '0.24';
+# Both these are needed for the find_base_dir funtion...
+use Gtk2;
+use Gtk2::Pango;
+
+our $VERSION = '0.28';
 our @ISA = qw/Zim::Formats/;
 
 =head1 NAME
@@ -113,9 +117,15 @@ sub _dump_node {
 	my ($name, $opt) = splice @$node, 0, 2;
 	
 	my @tags;
-	if ($name =~ /^head(\d+)/) { @tags = ("<h$1>", "</h$1>\n") }
+	if ($name =~ /^head(\d+)/) {
+		@tags = _is_rtl($node)
+			? ("<h$1 dir='rtl'>", "</h$1>\n")
+			: ("<h$1>", "</h$1>\n") ;
+	}
 	elsif ($name eq 'Para') {
-		@tags = ("<p>", "</p>\n");
+		@tags = _is_rtl($node)
+			? ("<p dir='rtl'>\n", "\n</p>\n")
+			: ("<p>\n", "\n</p>\n") ;
 		if (grep {!ref($_) and /^\s*\x{2022}\s+/m} @$node) {
 			# ugly hack ... should not be necessary
 			print $tags[0];
@@ -131,7 +141,11 @@ sub _dump_node {
 			shift @$node unless $$node[0] =~ /\S/;
 		}
 	}
-	elsif ($name eq 'Verbatim' ) { @tags = ("<pre>\n", "</pre>\n") }
+	elsif ($name eq 'Verbatim' ) { 
+		@tags = _is_rtl($node)
+			? ("<pre dir='rtl'>\n", "</pre>\n")
+			: ("<pre>\n", "</pre>\n") ;
+	}
 	elsif ($name eq 'bold'     ) { @tags = ('<b>', '</b>')   }
 	elsif ($name eq 'italic'   ) { @tags = ('<i>', '</i>')   }
 	elsif ($name eq 'underline') { @tags = ('<u>', '</u>')   }
@@ -172,12 +186,33 @@ sub _dump_node {
 		if (ref $_) { $class->_dump_node($_, $page) } # recurse
 		else {
 			s#([<>&])#\&$entities{$1}\;#g; # encode
+			s#\n#<br />\n#g unless $tags[0] =~ m#<pre>#;
 			print $_;
 		}
 	}
 	print $tags[1];
 }
 
+sub _is_rtl {
+	# walk tree for first piece of text and figure out whether it is ltr
+	# or not using Pango function
+	my $node = shift;
+	my $base = ($#$node > 1 and ref($$node[1] eq 'HASH')) ? 2 : 0;
+	for my $i ($base .. $#$node) {
+		if (ref $$node[$i]) {
+			my $is_ltr = _is_rtl($$node[$i]); # recurs
+			return $is_ltr if defined $is_ltr;
+		}
+		elsif (length $$node[$i]) {
+			my $dir = 'ltr'; # default
+			eval { $dir = Gtk2::Pango->find_base_dir($$node[$i]) };
+				# since Pango 1.4 - dies on gtk 2.4 install
+			return $dir eq 'rtl' ? 1 : 0;
+		}
+	}
+	return undef;
+}
+
 =item C<href(PAGE, LINK)>
 
 Function that returns both an url and a name for a link.
