@@ -4,7 +4,7 @@ use strict;
 no warnings;
 use Zim::Formats;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 our @ISA = qw/Zim::Formats/;
 
 # TODO: some tags can be nested: email links for example
@@ -72,6 +72,11 @@ sub load_tree { # TODO whitelines between verbatim blocks should be preserved
 			$first = 0;
 		}
 		else { # non-empty line
+			# next four lines by SIMON
+			if (/^\s*'''\s*$/ and $para ne '' and $verbatim == 0) {
+				push @tree, $class->parse_para($para, $page);
+				$para = '';
+			}
 			$verbatim = 1 if /^\s*'''\s*$/ and $para eq '';
 				# toggle verbatim at start of para
 			$para .= $_;
@@ -107,7 +112,7 @@ sub parse_para {
 	# Separate headers and paragraphs
 	return grep defined($_), map {
 		if (!/\S/) { undef }
-		elsif (/^==+\s+\S+/) { # header
+		elsif (/^==+\s+\S+/ and ! /\n/) { # header
 			$class->parse_head($_);
 		}
 		else { # paragraph
@@ -124,6 +129,7 @@ sub parse_head { # parse a header
 	$head =~ s/^(==+)\s+(.*?)(\s+==+\s*|\s*)$/$2/;
 	my $level = 7 - length($1); # =X6 => head1, =X5 => head2 etc.
 	$level = 1 if $level < 1;
+	$level = 5 if $level > 5; # just to be sure
 	return ['head'.$level, {}, $head];
 }
 
