@@ -20,7 +20,7 @@ my $has_mimeapplications = $@ ? 0 : 1;
 warn "WARNING: Could not use 'File::MimeInfo::Applications', disabling application bindings\n"
 	unless $has_mimeapplications;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
@@ -190,6 +190,7 @@ ToolsMenu	.		_Tools
 GoMenu		.		_Go
 HelpMenu	.		_Help
 PathBarMenu	.		P_athbar type
+ToolBarMenu	.		Toolbar style
 } );
 
 my $ui_actions = __actions(
@@ -245,7 +246,7 @@ TStatusBar	.		_Statusbar	.		Show statusbar
 TPane		gtk-index	_Index		F9		Show index
 } );
 
-my $ui_radio_actions = __actions(
+my $ui_radio_PBactions = __actions(
 # name,		stock id,	label,		accelerator,	tooltip
 q{
 PBRecent	.		_Recent pages	.		.
@@ -253,6 +254,23 @@ PBHistory	.		_History	.		.
 PBNamespace	.		_Namespace	.		.
 PBHidden	.		H_idden		.		.
 } );
+my $ui_radio_TBaction_iconsize = __actions(
+# name,		stock id,	label,		accelerator,	tooltip
+q{
+TBmenu		.		Tiny		.		.
+TBsmall-toolbar	.		Small		.		.
+TBbutton	.		Medium		.		.
+TBlarge-toolbar	.		Large		.		.
+TBdnd		.		Big		.		.
+TBdialog	.		Fat		.		.
+} );
+
+my $ui_radio_TBaction_style = __actions(
+q{
+TBtext		.		_Text	.		.
+TBicons		.		_Icons 	.		.
+TBboth		.		_Both	.		.
+} );
 
 my $ui_layout = q{<ui>
 	<menubar name='MenuBar'>
@@ -292,6 +310,18 @@ my $ui_layout = q{<ui>
 				<menuitem action='PBNamespace'/>
 				<menuitem action='PBHidden'/>
 			</menu>
+			<menu action='ToolBarMenu'>
+				<menuitem action='TBmenu'/>
+				<menuitem action='TBsmall-toolbar'/>
+				<menuitem action='TBbutton'/>
+				<menuitem action='TBlarge-toolbar'/>
+				<menuitem action='TBdnd'/>
+				<menuitem action='TBdialog'/>
+				<separator/>
+				<menuitem action='TBtext'/>
+				<menuitem action='TBicons'/>
+				<menuitem action='TBboth'/>
+			</menu>
 			<separator/>
 			<placeholder name='PluginItems'/>
 			<separator/>
@@ -369,6 +399,18 @@ my $ui_layout = q{<ui>
 		<menuitem action='popup_RenamePage'/>
 		<menuitem action='popup_DeletePage'/>
 	</popup>
+	<popup name='ToolBarPopup'>
+		<menuitem action='TBmenu'/>
+		<menuitem action='TBsmall-toolbar'/>
+		<menuitem action='TBbutton'/>
+		<menuitem action='TBlarge-toolbar'/>
+		<menuitem action='TBdnd'/>
+		<menuitem action='TBdialog'/>
+		<separator/>
+		<menuitem action='TBtext'/>
+		<menuitem action='TBicons'/>
+		<menuitem action='TBboth'/>
+	</popup>
 	<accelerator action='GoChild'/>
 </ui>};
 
@@ -574,7 +616,9 @@ sub gui_init {
 	$self->add_actions($ui_menus, 'MENU');
 	$self->add_actions($ui_actions);
 	$self->add_actions($ui_toggle_actions, 'TOGGLE');
-	$self->add_actions($ui_radio_actions, 'RADIO', 'TPathBar');
+	$self->add_actions($ui_radio_PBactions, 'RADIO', 'TPathBar');
+	$self->add_actions($ui_radio_TBaction_iconsize, 'RADIO', 'TBar_iconsize');
+	$self->add_actions($ui_radio_TBaction_style, 'RADIO', 'TBar_style');
 
 	$self->actions_set_sensitive(
 		Save      => $$self{read_only} ? 0 : 1,
@@ -596,6 +640,13 @@ sub gui_init {
 	$vbox->pack_start($self->{toolbar}, 0,1,0);
 	$self->{toolbar}->hide;
 	$self->{toolbar}->set_no_show_all(1);
+	$self->{toolbar}->signal_connect('popup_context_menu' => sub {
+		my $self = shift; # Gtk2::Toolbar
+		my ($x, $y, $b, $pop) = @_;
+		$pop->popup(undef, undef, undef, undef, 0, 0);
+	    },
+	    $ui->get_widget("/ToolBarPopup"),
+	);
 
 	## General window layout
 	my $hpaned = Gtk2::HPaned->new();
@@ -808,6 +859,10 @@ sub gui_show {
 	$self->TPathBar($pbtype);
 	$self->{message_lock} = 0;
 
+	## set toolbar styles
+	$self->TBar_style($$set{toolbar_style} || $self->{toolbar}->get_style);
+	$self->TBar_iconsize($$set{toolbar_iconsize} || $self->{toolbar}->get_icon_size);
+
 	## set autosave interval - default is every 5 seconds
 	my $t = $$set{save_interval} || 5000;
 	$self->{_save_timeout} =
@@ -1669,6 +1724,7 @@ sub EmailPage {
 	$self->SaveIfModified or return;
 	my $subject = $self->{page}->name;
 	my $src = $self->{page}->get_text;
+	$src =~ s/^Content-Type:.*?\n\n//s; # get rid of headers
 	$src =~ s/(\W)/sprintf '%%%02x', ord $1/eg; # url encoding
 	$self->open_url("mailto:?subject=$subject&body=".$src);
 }
@@ -2100,6 +2156,60 @@ sub TPathBar {
 	}
 }
 
+=item C<TBar_iconsize(SIZE)>
+
+Set the toolbar type to Gtk2::IconSize SIZE.
+
+=cut
+
+sub on_TBar_iconsize { # Gtk2::RadioAction, Gtk2::RadioAction, ZIM::GUI
+	my $self = pop;
+	return if $self->{_block_actions};
+	my $action = pop;
+	$action = lc substr($action->get_name, 2);
+	$self->TBar_iconsize($action);
+}
+
+sub TBar_iconsize {
+	my ($self, $type) = @_;
+	return warn "BUG: No toolbar type given" unless defined $type;
+	my $tool_bar = $self->{toolbar};
+	$tool_bar->set_icon_size($type);
+
+	$self->actions_show_active("TB$type" => 1);
+	unless ($$self{settings}{toolbar_iconsize} eq $type) {
+		$$self{settings}{toolbar_iconsize} = $type;
+		$self->SaveSettings; # not important enough for NOTIFY
+	}
+}
+
+=item C<TBar_style(VAL)>
+
+Set the toolbar type to Gtk2::ToolbarStyle
+
+=cut
+
+sub on_TBar_style { # Gtk2::RadioAction, Gtk2::RadioAction, ZIM::GUI
+	my $self = pop;
+	return if $self->{_block_actions};
+	my $action = pop;
+	$action = lc substr($action->get_name, 2);
+	$self->TBar_style($action);
+}
+
+sub TBar_style {
+	my ($self, $type) = @_;
+	return warn "BUG: No toolbar type given" unless defined $type;
+	my $tool_bar = $self->{toolbar};
+	$tool_bar->set_style($type);
+
+	$self->actions_show_active("TB$type" => 1);
+	unless ($$self{settings}{toolbar_style} eq $type) {
+		$$self{settings}{toolbar_style} = $type;
+		$self->SaveSettings; # not important enough for NOTIFY
+	}
+}
+
 =item C<Reload()>
 
 Save and reload the current page.
