@@ -9,7 +9,7 @@ use Gtk2::Gdk::Keysyms;
 use Zim::Utils;
 use Zim::GUI::Component;
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 our @ISA = qw/Zim::GUI::Component/;
 
 *CODESET = \$Zim::CODESET;
@@ -41,14 +41,11 @@ my ($k_return, $k_kp_enter, $k_space, $k_escape)
 sub init {
 	my $self = shift;
 	my $app = $self->{app};
-	$self->init_settings('Calendar Plugin', {Namespace => ':Date:'});
 
-	## Resolve namespace for calendar
-	my $namespace = $$self{settings}{Namespace};
-	$namespace = $app->{notebook}->resolve_page($namespace)->name;
-	$namespace =~ s/\:?$/:/;
-	$$self{settings}{Namespace} = $namespace;
-	$$self{namespace} = $namespace;
+	## Init settings
+	## plugin script already sets defaults and resolves namespace
+	$self->init_settings('Calendar Plugin');
+	$$self{namespace} = $$self{settings}{Namespace};
 
 	## Construct the dialog
 	my $dialog = Gtk2::Dialog->new(
