@@ -8,15 +8,15 @@ use Encode;
 use File::BaseDir 0.03 qw/data_dirs data_files/;
 use Zim::Events;
 use Zim::Utils;
-  
-our $VERSION = '0.25';
+
+our $VERSION = '0.27';
 
 our @ISA = qw/Zim::Events/;
 
 $Zim::ICON = data_files('pixmaps', 'zim.png');
 warn "WARNING: Could not find 'zim.png', is \$XDG_DATA_DIRS set properly ?\n"
 	unless length $Zim::ICON;
-  
+
 { # load all icons in pixmaps/zim
 	my @files = length($Zim::ICON) ? ($Zim::ICON) : ();
 	for my $dir (data_dirs('pixmaps', 'zim')) {
@@ -93,7 +93,7 @@ in the config file. Intended for use by plugin modules.
 
 When the whole section is missing it will be initialized with %DEFAULTS.
 
-When called on the main application object it will not change 
+When called on the main application object it will not change
 C<$$app{settings}> but only return the hash for the section requested.
 
 =item C<init_state(NAME, \%DEFAULTS)>
@@ -146,12 +146,15 @@ sub AUTOLOAD {
 	if ($AUTOLOAD =~ s/^on_(\w+)$/$1/) { # could be an action handler
 		my $self = pop;
 		return if $self->{_block_actions};
-		warn "## dispatch ACTION $AUTOLOAD\n";
 		if ($AUTOLOAD =~ s/^popup_//) { # popup menu
 			return $self->$AUTOLOAD(
 				defined($_popup_args) ? (@$_popup_args) : () );
 		}
-		else { return $self->$AUTOLOAD() }
+		else {
+			# GUI action, first try dispath, then default method
+			my $r = $self->signal_dispatch($AUTOLOAD);
+			return $r ? $r : $self->$AUTOLOAD();
+		}
 	}
 	elsif (ref $_[0]) {
 		my $self = shift;
@@ -186,14 +189,14 @@ sub add_actions {
 	my ($self, $actions, $type, $name) = @_;
 	$type = lc $type;
 	my $class = ref $self;
-	
+
 	unless ($self->{actions}) {
 		my $a = Gtk2::ActionGroup->new($class);
 		$self->{app}{ui}->insert_action_group($a, 0);
 		$self->{actions} = $a;
 	}
 	return $self->_add_radio_group($actions, $name) if $type eq 'radio';
-	
+
 	my @actions;
 	for (grep /\S/, split /\n/, $actions) {
 		my @a = map {($_ eq '.') ? undef : $_} split /\t+/, $_;
@@ -203,7 +206,7 @@ sub add_actions {
 		push @actions, \@a;
 	};
 	#use Data::Dumper; warn "Actions ($type): ", Dumper \@actions;
-	
+
 	($type eq 'toggle')
 		? $self->{actions}->add_toggle_actions(\@actions, $self)
 		: $self->{actions}->add_actions(\@actions, $self)  ;
@@ -212,7 +215,7 @@ sub add_actions {
 sub _add_radio_group {
 	my ($self, $actions, $name) = @_;
 	my $class = ref $self;
-	
+
 	my @l = grep /\S/, split /\n/, $actions;
 	my $val = 0;
 	my @actions;
@@ -283,7 +286,7 @@ sub actions_set_active {
 =item C<< actions_show_active($NAME => $VAL, ..) >>
 
 Like C<actions_set_active()> but prevents the action callback
-to be called. This method is used to make the appearance of 
+to be called. This method is used to make the appearance of
 the action match the state of the application.
 
 The blocking works at the level of our AUTOLOAD function.
@@ -317,10 +320,10 @@ Any ARGS are forwarded to the actions.
 sub popup {
 	my ($self, $name, $button, $time, @args) = @_;
 	my $menu = $self->{app}{ui}->get_widget('/'.$name) or return 0;
-    unless ($menu) {
-        carp "BUG: no such menu: $name";
-        return 0;
-    }
+	unless ($menu) {
+		carp "BUG: no such menu: $name";
+		return 0;
+	}
 	$_popup_args = scalar(@args) ? \@args : undef;
 	$menu->popup(undef, undef, undef, undef, $button, $time);
 	return 1;
@@ -334,14 +337,23 @@ sub popup {
 
 =item C<ShowHelp(PAGE)>
 
-Show a window showing the documentation. PAGE is optional.
+=item C<ShowHelp(NOTEBOOK, PAGE)>
+
+Show a window showing the documentation. Both PAGE and NOTEBOOK are optional.
+NOTEBOOK defaults to '_doc_' (same as C<--doc> on the commandline) but can
+be specified to be e.g. '_man_' (same as C<--man>).
+
+In the one argument form the page must start with a ':'.
 
 =cut
 
 sub ShowHelp {
-	my ($self, $page) = @_;
-	$self->call_daemon('open', '_doc_', $page) and return;
-	$self->exec_new_window('--doc', $page);
+	my ($self, $notebook, $page) = @_;
+	$notebook = '_doc_' if ! defined $notebook;
+	($notebook, $page) = ('_doc_', $notebook)
+		if ! defined $page and $notebook =~ /^:/;
+	$self->call_daemon('open', $notebook, $page) and return;
+	$self->exec_new_window($notebook, $page);
 }
 
 =back
@@ -422,7 +434,7 @@ sub check_file_input {
 	# Make it an uri to force resolve_file() to take is absolute.
 	$path = Zim::FS->path2uri($path)
 		if Zim::FS->is_abs_path($path) and -f $path;
-	
+
 	return $$self{app}{page}->resolve_file($path);
 }
 
@@ -466,21 +478,85 @@ sub encode_uri_list {
 
 Creates a button with a stock image but different text.
 
+=item C<new_small_button(STOCK)>
+
+Creates a small button without text.
+
 =cut
 
 sub new_button {
 	my ($self, $stock, $text) = @_;
+	my $button = Gtk2::Button->new();
+	$button->add(Gtk2::Alignment->new(0.5,0.5, 0,0));
 	my $hbox = Gtk2::HBox->new;
 	$hbox->pack_start(
 		Gtk2::Image->new_from_stock($stock, 'button'), 0,0,0);
 	$hbox->pack_start(
 		Gtk2::Label->new_with_mnemonic($text), 1,1,0);
-	my $button = Gtk2::Button->new();
-	$button->add(Gtk2::Alignment->new(0.5,0.5, 0,0));
 	$button->child->add($hbox);
 	return $button;
 }
 
+sub new_small_button {
+	my ($self, $stock) = @_;
+	my $button = Gtk2::Button->new();
+	$button->add(Gtk2::Alignment->new(0.5,0.5, 0,0));
+	$button->child->add(
+		Gtk2::Image->new_from_stock($stock, 'small-toolbar') );
+	return $button;
+}
+
+=item C<new_textview(TEXT)>
+
+Returns a L<Gtk2::ScrolledWindow> and a L<Gtk2::Textview>.
+Sets scrolling, shadow and margins properly.
+
+=cut
+
+sub new_textview {
+	my (undef, $text) = @_;
+
+	my $textview = Gtk2::TextView->new;
+	$textview->set_editable(0);
+	$textview->set_wrap_mode('word');
+	$textview->set_left_margin(5);
+	$textview->set_right_margin(5);
+	$textview->get_buffer->set_text($text) if defined $text;
+
+	my $scroll = Gtk2::ScrolledWindow->new;
+	$scroll->set_policy('automatic', 'automatic');
+	$scroll->set_shadow_type('in');
+	$scroll->add($textview);
+
+	return ($scroll, $textview);
+}
+
+=item C<set_treeview_single_click(TREEVIEW)>
+
+Make TREEVIEW a single click navigation widget.
+
+=cut
+
+sub set_treeview_single_click {
+	my $tview = pop;
+	$tview->signal_connect(
+		button_release_event => \&on_treeview_single_click);
+}
+
+
+sub on_treeview_single_click {
+	my ($tview, $event) = @_;
+	return 0 if $event->type ne 'button-release';
+
+	my ($x, $y) = $event->get_coords;
+	my ($path, $column) = $tview->get_path_at_pos($x, $y);
+	return 0 unless $path and $event->button == 1;
+	return 0 unless $tview->get_selection->path_is_selected($path);
+
+	$tview->row_activated($path, $column);
+	return 0;
+}
+
 =item C<list_text_targets(INFO)>
 
 Returns a list of targets used to copy-paste or drag-drop text.
@@ -513,17 +589,23 @@ TEXT, BUTTON_STOCK and BUTTON_TEXT are optional.
 
 sub new_prompt {
 	my ($self, $title, $fields, $data, $stock, $string, $text) = @_;
-	
+
 	## Setup dialog
 	$title .= ' - Zim';
+	my $window = $self->{app}{window} if ref $self;
+	$window = undef unless defined $window and $window->visible;
+		# window might not yet be realized
 	my $dialog = Gtk2::Dialog->new(
-		$title, $self->{app}{window},
+		$title, $window,
 		[qw/modal destroy-with-parent no-separator/],
 		'gtk-cancel'  => 'cancel',
 	);
 	#$dialog->set_resizable(0);
 	#$dialog->vbox->set_border_width(12); # FIXME
-	$dialog->set_icon($self->{app}{window}->get_icon);
+	my $icon = $window
+		? $window->get_icon
+		: Gtk2::Gdk::Pixbuf->new_from_file($Zim::ICON) ;
+	$dialog->set_icon($icon);
 	
 	$stock ||= 'gtk-ok';
 	my $button = $string
@@ -539,7 +621,7 @@ sub new_prompt {
 		$align->add($label);
 		$dialog->vbox->add($align);
 	}
-	
+
 	my ($table, $entries) = $self->new_form($fields, $data, $dialog);
 	$dialog->vbox->add($table);
 
@@ -579,11 +661,11 @@ sub new_form {
 	my @entries;
 	for my $i (0 .. $#$fields) {
 		my @f = @{ $$data{$$fields[$i]} };
-		
+
 		my $label = Gtk2::Label->new($f[0].':');
 		my $align = Gtk2::Alignment->new(0,0.5, 0,0);
 		$align->add($label);
-		
+
 		$table->attach($align, 0,1, $i,$i+1, ['fill'],[], 0,0);
 
 		my $entry;
@@ -617,6 +699,10 @@ sub new_form {
 		elsif ($f[1] eq 'int') {
 			# for integers we use a spin button input
 			my @r = @{$f[3]};
+			$r[0] ||= 0; # min
+			$r[1] = $r[0]+1 unless $r[1] > $r[0];
+				# Some Gtk versions do not allow max == min
+			$r[2] ||= 1; # step
 			$entry = Gtk2::SpinButton->new_with_range(@r);
 			$entry->set_value($f[2]);
 			$table->attach_defaults($entry, 1,2, $i,$i+1);
@@ -648,7 +734,7 @@ sub new_form {
 		}
 		push @entries, $entry;
 	}
-	
+
 	for my $i (0 .. $#entries - 1) {
 		$entries[$i]->signal_connect(
 			activate => sub { $entries[$i+1]->grab_focus } );
@@ -685,12 +771,12 @@ sub _update_completion {
 	$ns =~ s/[^:]+$//;
 	return if defined $entry->{_ns} and $entry->{_ns} eq $ns;
 	$entry->{_ns} = $ns;
-	
+
 	my $_ns = length($ns)
 		? $self->{app}{notebook}->resolve_namespace($ns)
 		: $self->{app}{page}->namespace() ;
 		#warn "Complete namespace: $_ns\n";
-	
+
 	my $model = $entry->get_completion->get_model;
 	$model->clear;
 	for ($self->{app}{notebook}->list_pages($_ns)) {
@@ -720,7 +806,7 @@ sub run_prompt {
 	return $values;
 }
 
-=item C<prompt_question(TITLE, TYPE, TEXT, BUTTONS ..., TIME)>
+=item C<prompt_question(TYPE, TEXT, BUTTONS ..., TIME)>
 
 TYPE can either be 'error', 'warning', 'question', 'info' or C<undef>.
 
@@ -741,7 +827,7 @@ triggering of a accelerator.
 sub prompt_question {
 	my ($self, $type, $text, @buttons) = @_;
 	my $time = pop @buttons unless ref $buttons[-1];
-	
+
 	my $dialog = Gtk2::Dialog->new(
 		undef, $self->{app}{window}, # HIG says no title
 	       	[qw/modal destroy-with-parent no-separator/],
@@ -758,9 +844,11 @@ sub prompt_question {
 			: $self->new_button($stock, $string)   ;
 		$button->set_sensitive(0);
 		$dialog->add_action_widget($button, $_);
+		$dialog->action_area->set_child_secondary($button, 1)
+			if $stock eq 'gtk-help';
 		push @button_widgets, $button;
 	}
-	
+
 	my $hbox = Gtk2::HBox->new(0,12); # spacing from HIG
 	$hbox->set_border_width(6); # border from HIG
 	$dialog->vbox->pack_start($hbox, 0,0,0);
@@ -802,7 +890,8 @@ sub prompt_question {
 	else { $_->set_sensitive(1) for @button_widgets }
 	my $id = $dialog->run;
 	$dialog->destroy;
-	
+
+	return undef unless $id =~ /^\d+$/;
 	return $buttons[$id][0];
 }
 
@@ -871,10 +960,10 @@ sub filechooser_dialog {
 		? ( $$self{app}{page}->document_dir,
 		    $$self{app}{notebook}->document_dir,
 		    $$self{app}{notebook}->document_root )
-		: (undef, undef) ;
+		: (undef, undef, undef) ;
 		# need to check page here because this method is also
 		# used by e.g. NotebookDialog
-	
+
 	# construct filechooser dialog
 	my $dialog;
 	$title ||= $want_dir
@@ -891,13 +980,13 @@ sub filechooser_dialog {
 	# add links to special directories in side pane
 	for (grep {defined $_} $doc_root, $doc_dir_root, $doc_dir) {
 		my $folder = Zim::FS->localize($_);
-		eval { $dialog->add_shortcut_folder($folder) } if -e $folder; 
+		eval { $dialog->add_shortcut_folder($folder) } if -e $folder;
 			# dies for some gtk version if folder does not exist
 			# dies for other gtk version if shortcut is double
 	}
-	
+
 	# set the file or dir we want the dialog to open
-	if (defined $file) {
+	if (defined $file and $file =~ /\S/) {
 		# opens the dir for file (file can be a dir itself)
 		$file = Zim::FS->localize(file($file));
 		$dialog->set_filename($file);
