@@ -19,7 +19,7 @@ use Zim::GUI::Component;
 eval "use Gtk2::Ex::DesktopEntryMenu";
 my $has_mimeapplications = $@ ? 0 : 1;
 
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 
 our @ISA = qw/Zim::GUI::Component/;
 
@@ -78,6 +78,8 @@ qq{
 Undo		gtk-undo	_Undo		<ctrl>Z		Undo
 Redo		gtk-redo	_Redo		<ctrl><shift>Z	Redo
 Delete		gtk-delete	_Delete		.		Delete
+ToggleCheckbox	checked-box	Toggle Checkbox 'V'	F12	Toggle checkbox
+XToggleCheckbox	xchecked-box	Toggle Checkbox 'X'	<shift>F12	Toggle checkbox
 EditObject	gtk-properties	_Edit Link...	<ctrl>E		Edit link
 InsertDate	.		_Date and Time...	<ctrl>D	Insert date
 InsertLink	gtk-connect	_Link...		.	Insert link
@@ -133,6 +135,8 @@ my $ui_layout = q{<ui>
 				<menuitem action='Paste'/>
 				<menuitem action='Delete'/>
 				<separator/>
+				<menuitem action='ToggleCheckbox'/>
+				<menuitem action='XToggleCheckbox'/>
 				<menuitem action='EditObject'/>
 				<separator/>
 			</placeholder>
@@ -251,7 +255,6 @@ sub init { # called by new()
 		# initial_size, pos_in_pixels, ... allign => position
 		1, 1, 'left' => $$style{tabs} ) )
 		if $$style{tabs};
-	$htext->{follow_on_enter} = $self->{app}{settings}{follow_on_enter};
 	$htext->signal_connect(link_clicked =>
 		sub { $self->{app}->link_clicked($_[1]) }  );
 	$htext->signal_connect(link_enter =>
@@ -288,9 +291,6 @@ sub init { # called by new()
 	$self->{htext} = $htext;
 	$self->{widget} = $htext;
 
-	$self->set_font($self->{app}{settings}{textfont})
-		if defined $self->{app}{settings}{textfont};
-
 	# init search box
 	my $hbox = Gtk2::HBox->new(0, 5);
 	$hbox->set_no_show_all(1);
@@ -298,11 +298,8 @@ sub init { # called by new()
 	$vbox->pack_start($hbox, 0, 1, 3);
 	$self->{hbox} = $hbox;
 	
-	my $close_button = Gtk2::Button->new;
+	my $close_button = $self->new_small_button('gtk-close');
 	$close_button->set_relief('none');
-	$close_button->add(Gtk2::Alignment->new(0.5, 0.5, 0, 0));
-	$close_button->child->add(
-		Gtk2::Image->new_from_stock('gtk-close', 'small-toolbar') );
 	$close_button->signal_connect_swapped(
 		clicked => \&CloseFind, $self );
 	$hbox->pack_end($close_button, 0,1,0);
@@ -370,7 +367,20 @@ sub init { # called by new()
 	$self->{sendto_dir} = $sendto_dir if -d $sendto_dir;
 	#warn "sendTo dir: $sendto_dir\n";
 	
+	$$self{app}->signal_connect(
+		'settings-changed' => \&on_load_settings, $self);
+	$self->on_load_settings;
 	$self->on_show_cursor;
+
+}
+
+sub on_load_settings {
+	my $self = pop;
+	my $settings = $$self{app}{settings};
+	$$self{htext}{follow_on_enter} = $$settings{follow_on_enter};
+	$$self{htext}{use_recurscheck} = $$settings{use_recurscheck};
+	$self->set_font($$settings{textfont})
+		if defined $$settings{textfont};
 }
 
 sub _init_buffer {
@@ -386,7 +396,7 @@ sub _init_buffer {
 	$buffer->signal_connect(edit_mode_changed =>
 		\&on_edit_mode_changed, $self );
 	$self->on_show_cursor;
-	$buffer->{_zim_name} = $self->{app}{name}; # FIXME FIXME FIXME
+	$buffer->{_zim_name} = $self->{app}{notebook}{name}; # FIXME FIXME FIXME
 }
 
 =back
@@ -597,6 +607,28 @@ sub Delete {
 	$$self{htext}->signal_emit('delete_from_cursor', 'chars', 1);
 }
 
+=item C<ToggleCheckbox(ITER, TYPE)>
+
+=item C<XToggleCheckbox(ITER)>
+
+Same as ToggleCheckbox with type 'x'.
+
+=cut
+
+sub ToggleCheckbox {
+	my ($self, $iter, $type) = @_;
+	$type ||= 'v';
+	$iter ||= $$self{buffer}->get_iter_at_mark(
+			$$self{buffer}->get_insert() );
+	my $lf = $$self{buffer}->get_iter_at_line( $iter->get_line );
+	my $line = $$self{buffer}->get_slice($lf, $iter, 0);
+	return unless $line =~ /^(\s*)\x{FFFC}/;
+	$lf->forward_chars(length $1);
+	$$self{htext}->toggle_if_checkbox_at_iter($lf, $type);
+}
+
+sub XToggleCheckbox { $_[0]->ToggleCheckbox($_[1], 'x') }
+
 =item C<EditObject(ITER)>
 
 Dispatches to C<EditLink()>, C<EditImage()> or a custom handler
@@ -615,7 +647,7 @@ sub EditObject {
 		$self->EditLink($iter);
 	}
 	elsif (my $pixbuf = $iter->get_pixbuf) {
-		$self->EditImage($iter);
+		$self->EditImage($iter) unless $$pixbuf{type} eq 'checkbox';
 	}
 	else {
 		my ($start, $end) = $$self{buffer}->get_selection_bounds;
@@ -789,6 +821,9 @@ sub prompt_date_format {
 		'gtk-cancel'  => 'cancel',
 	);
 	my $button = $self->new_button(
+		'gtk-properties', __('_Edit')); #. dialog button
+	$dialog->add_action_widget($button, 42);
+	$button = $self->new_button(
 		'gtk-ok', __('_Insert')); #. dialog button
 	$dialog->add_action_widget($button, 'ok');
 	
@@ -804,20 +839,23 @@ sub prompt_date_format {
 	$check->set_active($l);
 	$dialog->vbox->add($check);
 
-	my ($file) = data_files('zim', 'dates.list');
+	my $file = data_files('zim', 'dates.list');
 	my @dates;
-	if (defined $file) {
-		for (file($file)->read()) {
-			chomp;
-			! /^\s*#/ and /\S/ or next;
-			push @dates, $_;
-		}
+ 	if (defined $file) {
+ 		for (file($file)->read()) {
+ 			chomp;
+ 			! /^\s*#/ and /\S/ or next;
+ 			push @dates, $_;
+ 		}
+ 	}
+ 	else { @dates = ('%A %d/%m/%Y', '%A %d/%m/%Y %H:%M', '%c', '%x') }
+
+	# For some reason perl 5.10 segfaults if we use a map {} here !?
+	foreach (@dates) {
+	    push @{$view->{data}},
+	    	Encode::decode($CODESET, strftime($_, @$date));
 	}
-	else { @dates = ('%A %d/%m/%Y', '%A %d/%m/%Y %H:%M', '%c', '%x') }
-	@{$view->{data}} =
-		map Encode::decode($CODESET, strftime($_, @$date)),
-		@dates ;
-	
+
 	my $i = $self->{app}{settings}{recent_date_format};
 	$view->select($i) if defined $i;
 	
@@ -831,6 +869,15 @@ sub prompt_date_format {
 		$dialog->destroy;
 		return ($l, $dates[$i]);
 	}
+	elsif ($r == 42) {
+		$file = data_files('zim', 'dates.list');
+		my $rw_file = data_home('zim', 'dates.list');
+		file($file)->copy($rw_file)
+			if $file ne $rw_file and not -e $rw_file;
+		$$self{app}->EditSource(undef, $rw_file); # using private arg
+		$dialog->destroy;
+		return $self->prompt_date_format($date); # recurs
+	}
 	else {
 		$dialog->destroy;
 		return undef;
@@ -1092,7 +1139,7 @@ sub on_drag_data_received {
 	my @items = $self->decode_uri_list($data);
 	my @blocks;
 	if ($type eq 'text/x-zim-page-list') {
-		my $rep = $$self{app}{name};
+		my $rep = $$self{app}{notebook}{name};
 		@blocks = map {
 			if (s/^\Q$rep\E\?//) {
 				$_ = $self->{app}{page}->relative_name($_);
@@ -1598,11 +1645,13 @@ sub parse_backspace {
 	my ($self, $iter) = @_;
 	my $buffer = $self->{buffer};
 	my $lf = $buffer->get_iter_at_line( $iter->get_line );
-	my $line = $buffer->get_text($lf, $iter, 0);
-	if ($line =~ s/\t([\*\x{2022}]\s)$/$1/) {
+	my $line = $buffer->get_slice($lf, $iter, 0);
+	if ($line =~ /\t([\*\x{2022}\x{FFFC}]\s)$/) {
+		$iter->backward_chars(length $1);
+		my $begin = $iter->copy;
+		$begin->backward_char;
 		_user_action_ {
-			$buffer->delete($lf, $iter);
-			$buffer->insert($lf, $line);
+			$buffer->delete($begin, $iter);
 		} $buffer;
 		return 1;
 	}
@@ -1657,9 +1706,15 @@ sub parse_line {
 		} $buffer;
 		return 1;
 	}
-	elsif ($line =~ /^(\s*(:?\W+|\d+\W?|\w\W)\s+|\s+)$/) { # empty bullet or list item
-		return 0 if $line =~ /\x{fffc}/; # embedded image
+	elsif ($line =~ /^(\s*(:?\W+|\d+\W?|\w\W)(\s+)|\s+)$/) { # empty bullet or list item
+		my $post = $2;
 		# TODO check previous line for same pattern !
+		if ($line =~ /\x{FFFC}/) { # embedded image or checkbox
+			my $i = $iter->copy;
+			$i->backward_chars(length($post)+1);
+			my $pixbuf = $i->get_pixbuf;
+			return 0 unless $pixbuf and $$pixbuf{image_data}{type} eq 'checkbox';
+		}
 		_user_action_ { $buffer->delete($lf, $iter) } $buffer;
 	}
 #	elsif ($line =~ /^(\s*(\w+)\W\s+)/ and isroman($2)) {
@@ -1673,17 +1728,36 @@ sub parse_line {
 #		$self->{htext}->scroll_mark_onscreen( $buffer->get_insert() );
 #		return 1;
 #	}
-	elsif ($line =~ /^(\s*(:?\W+|\d+\W?|\w\W)\s+|\s+)/) { # auto indenting + lists
-		my ($indent, $number) = ($1, $2);
-		if (length $number) { # numbered list
-			$number = ($number =~ /\d/) ? $number+1 : chr(ord($number)+1);
-			$indent =~ s/^(\s*)(\d+|\w)/$1$number/;
+	elsif ($line =~ /^(\s*(\W+|\d+\W?|\w\W)(\s+)|\s+)/) { # auto indenting + aotu incremnt lists
+		my ($indent, $number, $post) = ($1, $2, $3);
+		$number =~ s/\W//g;
+		if ($indent =~ /\x{FFFC}/) { # embedded image or checkbox
+			my $i = $lf->copy;
+			$i->forward_chars(length($indent)-length($post)-1);
+			my $pixbuf = $i->get_pixbuf;
+			return 0 unless $pixbuf and $$pixbuf{image_data}{type} eq 'checkbox';
+		}
+		elsif (length $number) { # numbered list
+			return 0 unless $$self{app}{settings}{use_autoincr};
+			$number = ($number =~ /\d/)
+				? $number+1
+				: chr(ord($number)+1) ;
+			$indent =~ s/(\d+|\w)/$number/;
 		}
 		my $offset = $iter->get_offset;
 		_user_action_ { $buffer->insert($iter, "\n") } $buffer;
 		$iter = $buffer->get_iter_at_offset($offset);
 		$iter->forward_char;
-		_user_action_ { $buffer->insert($iter, "$indent") } $buffer;
+		if ($indent =~ /\x{FFFC}/) { # checkbox
+			my ($begin, $end) = split /\x{FFFC}/, $indent, 2;
+			$buffer->insert_blocks_at_cursor(
+				$begin, ['checkbox', {state => 0}], $end)
+		}
+		else {
+			_user_action_ {
+				$buffer->insert($iter, "$indent")
+			} $buffer;
+		}
 		$self->{htext}->scroll_mark_onscreen( $buffer->get_insert() );
 		return 1;
 	}
@@ -1710,25 +1784,62 @@ sub parse_word {
 	my $lf = $iter->copy;
 	$self->{htext}->backward_display_line_start($lf)
 		unless $self->{htext}->starts_display_line($lf);
-	my $line = $buffer->get_text($lf, $iter, 0);
+	my $line = $buffer->get_slice($lf, $iter, 0);
 	#warn ">>$line<< >>$char<<\n";
-	if ($line =~ /^(\s*)[\*\x{2022}](\s*)$/) { # bullet
+	if ($line =~ /^\s*([\*\x{2022}\x{FFFC}]|(?:[\*\x{2022}]\s*)?\[[ *xX]?\])(\s*)$/) {
+		# bullet or checkbox (or checkbox prefixed with bullet)
 		return unless $lf->starts_line; # starts_display_line != starts_line
-		my ($pre, $post) = ($1, $2.$char);
+		my ($bullet, $post) = ($1, $2);
+		if ($bullet eq "\x{FFFC}") {
+			my $i = $iter->copy;
+			$i->backward_chars(length($bullet.$post));
+			my $pixbuf = $i->get_pixbuf;
+			return unless $pixbuf and $$pixbuf{image_data}{type} eq 'checkbox';
+		}
 		my $offset;
 		if (defined $char) {
-			($lf, $offset) = ($lf->get_offset, $iter->get_offset);
+			# insert char 
+			$offset = $iter->get_offset;
 			_user_action_ { $buffer->insert($iter, $char) } $buffer;
-			($lf, $iter) = map $buffer->get_iter_at_offset($_), $lf, $offset;
-			$iter->forward_char;
-			$pre .= $1 if $post =~ s/(\t+)$//; # switch tabs
-			$post = ' ' unless length $post;
+			$iter = $buffer->get_iter_at_offset($offset);
+			if (defined $char and $char eq "\t") {
+				# delete the char again and indent
+				my $end = $iter->copy;
+				$end->forward_char;
+				_user_action_ {
+					$buffer->delete($iter, $end);
+					$iter = $buffer->get_iter_at_offset($offset);
+					$buffer->insert($iter, ' ') unless length $post;
+					$iter = $buffer->get_iter_at_offset($offset);
+					$iter->backward_chars(length $bullet.$post);
+					$buffer->insert($iter, "\t");
+				} $buffer;
+				$iter = $buffer->get_iter_at_offset($offset+1);
+			}
+		}
+		my $end = $iter->copy;
+		$iter->backward_chars(length $bullet.$post);
+		$end->backward_chars(length $post);
+		if ($bullet eq '*') {
+			# format bullet
+			_user_action_ {
+				$buffer->delete($iter, $end);
+				$buffer->insert($iter, "\x{2022}");
+			} $buffer;
+		}
+		elsif ($bullet =~ /\[([ *xX]?)\]/) {
+			# format checkbox
+			my $state = ($1 eq '*') ? 1 : (lc($1) eq 'x') ? 2 : 0 ;
+			$offset = $iter->get_offset;
+			_user_action_ {
+				$buffer->delete($iter, $end);
+				$buffer->place_cursor($iter);
+				$buffer->insert_blocks_at_cursor(['checkbox', {state => $state}]);
+			} $buffer;
+			$iter = $buffer->get_iter_at_offset($offset+1);
+			$iter->forward_chars(length($post)+1);
+			$buffer->place_cursor($iter);
 		}
-		$line = $pre."\x{2022}".$post;
-		_user_action_ {
-			$buffer->delete($lf, $iter);
-			$buffer->insert($lf, $line);
-		} $buffer;
 		return 1;
 	}
 	elsif (
@@ -1751,7 +1862,7 @@ sub parse_word {
 	) { # any kind of link
 		my $word = $1;
 		return 0 if $word !~ /[[:alpha:]]{2}/; # at least two letters in there
-		#return 0 unless $word =~ /[^:\dhu]/i; # do not link "10:20h"
+		return 0 if $word =~ /^\d+:/; # do not link "10:20h", "10:20PM" etc.
 		my ($start, $end) = ($iter->copy, $iter->copy);
 		$start->backward_chars(length $word);
 		return 0 if grep {$_->get_property('name') !~ /spell/}
