@@ -7,7 +7,7 @@ use Gtk2::Gdk::Keysyms;
 use Zim::Utils;
 use Zim::GUI::Component;
 
-our $VERSION = '0.24';
+our $VERSION = '0.28';
 our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
@@ -41,7 +41,7 @@ sub init { # called by new()
 	my $self = shift;
 
 	my $scroll_window = Gtk2::ScrolledWindow->new();
-	$scroll_window->set_policy('automatic', 'automatic');
+	$scroll_window->set_policy('never', 'automatic');
 	$scroll_window->set_shadow_type('in');
 	$self->{scroll_window} = $scroll_window;
 
@@ -50,6 +50,7 @@ sub init { # called by new()
 
 	my $tree_view = Gtk2::TreeView->new($tree_store);
 	my $renderer = Gtk2::CellRendererText->new();
+	$renderer->set_property(ellipsize => 'end');
 	$renderer->signal_connect_swapped(edited => \&on_cell_edited, $self);
 	$self->{renderer} = $renderer;
 	my $page_column = Gtk2::TreeViewColumn->new_with_attributes(
@@ -107,7 +108,7 @@ sub on_drag_data_get { # we are drag source
         my ($self, $context, $selection_data, $info, $time) = @_;
 	return unless $info == 0; # text/x-zim-page-list
 
-	my $rep = $self->{app}{name};
+	my $rep = $self->{app}{notebook}{name};
 	warn "BUG: no notebook name set!" unless length($rep);
 	my @pages = map "$rep?$_", grep length($_), map {$self->path2page($_)}
 		$self->{tree_view}->get_selection->get_selected_rows;
@@ -135,7 +136,7 @@ sub on_drag_data_received { # we are drag target
 	my $node_ns = ($pos =~ /into/) ? $node.':' : $1;
 	$page =~ /^(.*?)\?(.*:)(.+)/ or return;
 	my ($rep, $ns, $basename) = ($1, $2, $3);
-	if ($rep ne $$self{app}{name} or $ns eq $node_ns) {
+	if ($rep ne $$self{app}{notebook}{name} or $ns eq $node_ns) {
 		# either from a different notebook
 		# or in the same namespace
 		# => failure
@@ -442,12 +443,13 @@ If TMP is true the page is temporarily added when it did not yet exist.
 
 sub select_page {
 	my ($self, $page, $tmp) = @_;
-	my $path = $self->page2path($page);
 	if ($$self{tmp_listed} and $$self{tmp_listed} ne $page) {
 		# Remove a previously temp listed page when changing selection.
 		$self->unlist_page($$self{tmp_listed});
 		$$self{tmp_listed} = undef;
 	}
+
+	my $path = $self->page2path($page);
 	if (! $path && $tmp) {
 		# If page does not exist (or wasn't listed for some reason)
 		# we list it temporarily and select it
