@@ -7,18 +7,19 @@
 # TRANSLATORS:
 # Frederik 'Freso' S. Olesen (da)
 # Jeppe Toustrup (da)
+# nanker (da)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
 # POT-Creation-Date: 2008-10-27 21:09+0100
-# PO-Revision-Date: 2008-09-30 11:39+0000
-# Last-Translator: Peter Skov <Unknown>
+# PO-Revision-Date: 2008-12-13 12:25+0000
+# Last-Translator: nanker <Unknown>
 # Language-Team: Danish <da@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-11-09 09:04+0000
+# X-Launchpad-Export-Date: 2009-02-17 18:56+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -101,8 +102,8 @@ opretter navnerum for hver måned.
   'Bold' => 'Fed',
   'Calen_dar|Show calendar' => '_Kalender|Vis kalender',
   'Calendar' => 'Kalender',
-  'Can not find application "bzr"' => '',
-  'Can not find application "{name}"' => '',
+  'Can not find application "bzr"' => 'Kan ikke finde applikation "bzr"',
+  'Can not find application "{name}"' => 'Kan ikke finde applikation "{name}"',
   'Can not save a version without comment' => 'Det er ikke muligt at gemme uden en kommentar',
   'Can not save to page: {name}' => 'Siden "{name}" kan ikke gemmes',
   'Can\'t find {url}' => 'Adressen "{url}" kunne ikke findes',
@@ -114,7 +115,7 @@ opretter navnerum for hver måned.
   'Choose {app_type}' => 'Vælg {app_type}',
   'Co_mpare Page...' => 'S_ammeling side',
   'Command' => 'Kommando',
-  'Comment' => '',
+  'Comment' => 'Kommentar',
   'Compare this version with' => 'Sammeling denne version med',
   'Copy Email Address' => 'Kopiér _post adresse',
   'Copy Location|Copy location' => 'Kopiér _placering|Kopiér adressen til den aktive side',
@@ -163,7 +164,7 @@ opretter navnerum for hver måned.
   'Failed to load SVN plugin,
 do you have subversion utils installed?' => '',
   'Failed to load plugin: {name}' => 'Udvidelsesmodulet "{name}" kunne ikke indlæses',
-  'Failed update working copy.' => '',
+  'Failed update working copy.' => 'Opdatering af arbejdskopi mislykkedes.',
   'File browser' => 'Filvælger',
   'File is not a text file: {file}' => 'Filen "{file}" er ikke en tekstfil',
   'Filter' => 'Filter',
@@ -212,7 +213,7 @@ do you have subversion utils installed?' => '',
   'New notebook' => 'Ny notesblok',
   'New page' => 'Ny side',
   'No such directory: {name}' => 'Mappen "{name}" findes ikke',
-  'No such file or directory: {name}' => '',
+  'No such file or directory: {name}' => 'Ikke sådan en fil eller mappe: {name}',
   'No such file: {file}' => 'Filen "{file}" kunne ikke findes',
   'No such notebook: {name}' => 'Notesbogen "{name}" findes ikke',
   'No such page: {page}' => 'Siden findes ikke: {page}',
@@ -238,7 +239,7 @@ bliver der også automatisk oprettet en ny side.',
   'Page Editable|Page editable' => 'Side redigerbar|Ændre på hvorvidt der er mulighed for at redigere siden',
   'Page name' => 'Sidenavn',
   'Pages' => 'Sider',
-  'Password' => '',
+  'Password' => 'Adgangskode',
   'Please enter a comment for this version' => 'Indtast en kommentar til denne version',
   'Please enter a name to save a copy of page: {page}' => 'Indtast venligst et navn for at gemme en kopi af siden: {page}',
   'Please enter a {app_type}' => 'Indtast venligst en {app_type}',
@@ -249,7 +250,8 @@ For example a "Notes" directory in your home dir.' => 'Angiv som minimum en mapp
 Til en ny noteblok skal denne mappe være tom.
 For eksempel en mappe "Noter" i din hjemmemappe.',
   'Please provide the password for
-{path}' => '',
+{path}' => 'Angiv venligst adgangskoden for
+{path}',
   'Please select a notebook first' => 'Vælg venligst en notesblok først',
   'Please select a version first' => 'Angiv venligst en version først',
   'Plugin already loaded: {name}' => 'Udvidelsesmodulet "{name}" er allerede indlæst',
@@ -309,8 +311,8 @@ mangler. Det er ikke muligt at redigere ligningen.',
   'This page was updated in the repository.
 Please update your working copy (Tools -> SVN update).' => '',
   'To_day|Today' => '_I dag|Gå til i dags dato',
-  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
-  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => '',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => '',
   'Underline' => 'Understreg',
   'Updating links' => 'Opdaterer henvisninger',
   'Updating links in {name}' => 'Opdaterer henvisninger i {name}',
@@ -358,7 +360,7 @@ for plugin changes to take effect.' => 'Du bliver nød til at genstarte programm
   '_Delete Page|Delete page' => '_Slet side|Slet den aktive side',
   '_Delete|Delete' => '_Slet|Slet tekst eller elementer',
   '_Discard changes' => 'For_kast ændringer',
-  '_Edit' => '',
+  '_Edit' => 'R_edigér',
   '_Edit Equation' => '_Redigér ligning',
   '_Edit Link' => '_Redigér henvisning',
   '_Edit Link...|Edit link' => '_Redigér henvisning...|Redigér en eksisterende henvisning',
