@@ -1,17 +1,36 @@
+# German translation for zim
+# Copyright (c) 2007 Rosetta Contributors and Canonical Ltd 2007
+# This file is distributed under the same license as the zim package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2007.
+# 
+# 
+# TRANSLATORS:
+# Hokey (de)
+# Jaap Karssenberg (de)
+# Klaus Vormweg (de)
+# Matthias Mailänder (de)
+# Nikolaus Klumpp (de)
+# René 'Necoro' Neumann (de)
+# 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-05-08 00:12+0800
-# PO-Revision-Date: 2008-05-13 20:25+0000
-# Last-Translator: Matthias Mailänder <matthias@mailaender.name>
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2008-11-03 20:47+0000
+# Last-Translator: Klaus Vormweg <klaus.vormweg@gmx.de>
 # Language-Team: German <de@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
-# X-Launchpad-Export-Date: 2008-05-19 15:32+0000
+# Plural-Forms: nplurals=2; plural=n != 1;
+# X-Launchpad-Export-Date: 2008-11-09 09:04+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
 
+# Subroutine to determine plural:
+sub {my $n = shift; $n != 1},
+
+# Hash with translation strings:
 {
   '%a %b %e %Y' => '%a %b %e %Y',
   '<b>Delete page</b>
@@ -21,6 +40,13 @@ page \'{name}\' ?' => '<b>Seite löschen</b>
 
 Sind Sie sicher, dass sie die Seite
 \'{name}\' löschen wollen?',
+  '<b>Enable Version Control</b>
+
+Version control is currently not enabled for this notebook.
+Do you want to enable it ?' => '<b>Versionskontrolle einschalten</b>
+
+Versionskontrolle ist für dieses Notizbuch nicht aktiviert.
+Wollen Sie sie einschalten?',
   '<b>Folder does not exist.</b>
 
 The folder: {path}
@@ -37,6 +63,17 @@ Do you want to overwrite it?' => '<b>Seite existiert schon</b>
 Die Seite \'{name}\'
 exisitiert schon. Wollen Sie
 sie überschreiben?',
+  '<b>Restore page to saved version?</b>
+
+Do you want to restore page: {page}
+to saved version: {version} ?
+
+All changes since the last saved version will be lost !' => '<b>Seite durch eine ältere Version ersetzen!</b>
+
+Wollsen Sie die Seite: {page}
+durch die Version {version} ersetzen?
+
+Alle Änderungen nach dieser Version gehen verloren!',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -53,6 +90,7 @@ einen Namensraum pro Monat.
 Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
 ',
   'Add \'tearoff\' strips to the menus' => 'Menüs \'abreißbar\' machen',
+  'Application show two text files side by side' => 'Programm, um zwei Textdateien nebeneinander darzustellen',
   'Application to compose email' => 'Mailprogramm',
   'Application to edit text files' => 'Text Editor',
   'Application to open directories' => 'Dateibrowser',
@@ -60,33 +98,57 @@ Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
   'Attach _File|Attach external file' => 'Anhang hinzu_fügen|Eine externe Datei hinzufügen',
   'Attach external files' => 'Externe Dateien anhängen',
   'Auto-format entities' => 'Automatische Umsetzung von Sonderzeichen',
+  'Auto-increment numbered lists' => 'Automatisches Hochzählen numerierter Listen',
   'Auto-link CamelCase' => 'KamelSchreibWeise automatisch verlinken',
   'Auto-link files' => 'Dateien automatisch verlinken',
+  'Auto-save version on close' => 'Automatisches Speichern der Version beim Schließen',
   'Auto-select words' => 'Worte automatisch markieren',
+  'Automatically increment items in a numbered list' => 'Zählt automatisch die Einträge einer numerierten Liste',
   'Automatically link file names when you type' => 'Dateien während der Eingabe automatisch verlinken',
   'Automaticly link CamelCase words when you type' => 'Worte in KamelSchreibWeise während der Eingabe automatisch verlinken',
   'Automaticly select the current word when you toggle the format' => 'Markiert das aktuelle Wort automatisch, wenn Sie die Formatierung ändern',
   'Bold' => 'Fett',
   'Calen_dar|Show calendar' => '_Kalender|Öffne Kalenderfenster',
   'Calendar' => 'Kalender',
+  'Can not find application "bzr"' => 'Kann das Programm "bzr" nicht finden',
+  'Can not find application "{name}"' => 'Kann die Anwendung "{name}" nicht finden',
+  'Can not save a version without comment' => 'Fassungen ohne Beschreibung können nicht gespeichert werden',
   'Can not save to page: {name}' => 'Kann Seite {name} nicht speichern',
   'Can\'t find {url}' => 'Finde {url} nicht',
   'Cha_nge' => 'Ä_ndern',
   'Chars' => 'Zeichen',
   'Check _spelling|Spell check' => '_Rechtschreibprüfung|Rechtschreibprüfung',
+  'Check checkbox lists recursive' => 'Ankreuzlisten rekursiv ankreuzen',
+  'Checking a checkbox list item will also check any sub-items' => 'Ankreuzen eines Ankreuzfelds wird auch alle darunter liegenden Felder ankreuzen',
   'Choose {app_type}' => 'Wähle {app_type}',
+  'Co_mpare Page...' => '_Vergleiche Seite...',
   'Command' => 'Befehl',
+  'Comment' => 'Kommentar',
+  'Compare this version with' => 'Diese Fassung vergleichen mit',
   'Copy Email Address' => 'E-Mail Adresse kopieren',
   'Copy Location|Copy location' => 'Kopiere Seiten_adresse|Adresse der Wikiseite in die Zwischenablage kopieren',
   'Copy _Link' => 'Kopiere _Link',
   'Could not delete page: {name}' => 'Konnte Seite {name} nicht löschen',
+  'Could not get annotated source for page {page}' => 'Konnte den Quelltext mit Anmerkungen für die Seite {page} nicht laden',
+  'Could not get changes for page: {page}' => 'Kann auf die Änderungen für die Seite "{page}" nicht zugreifen',
+  'Could not get changes for this notebook' => 'Konnte Änderungen für dieses Notizbuch nicht lesen',
+  'Could not get file for page: {page}' => 'Kann auf die Datei für die Seite "{page}" nicht zugreifen',
+  'Could not get versions to compare' => 'Kann auf die zu vergleichenden Fassungen nicht zugreifen',
+  'Could not initialize version control' => 'Kann die Versionskontrolle nicht initialisieren.',
   'Could not load page: {name}' => 'Konnte Seite {name} nicht öffnen',
   'Could not rename {from} to {to}' => 'Umbenennen von {from} nach {to} ist gescheitert',
   'Could not save page' => 'Speichern der Seite fehlgeschlagen',
+  'Could not save version' => 'Konnte Fassung nicht speichern',
   'Creating a new link directly opens the page' => 'Wenn Sie einen neuen Link erzeugen, öffnen Sie damit eine neue Seite',
+  'Creation Date' => 'Erstellungsdatum',
   'Cu_t|Cut' => 'Aus_schneiden|Ausschneiden',
+  'Current' => 'Aktuell',
   'Customise' => 'Anpassen',
   'Date' => 'Datum',
+  'Default notebook' => 'Standard-Notizbuch',
+  'Details' => 'Details',
+  'Diff Editor' => 'Diff-Editor',
+  'Diff editor' => 'Diff-Editor',
   'Directory' => 'Verzeichnis',
   'Document Root' => 'Zim-Startverzeichnis',
   'E_quation...|Insert equation' => '_Formel...|Formel einfügen',
@@ -106,7 +168,12 @@ Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
   'Expand side pane' => 'Seitenleiste erweitern',
   'Export page' => 'Exportiere Seite',
   'Exporting page {number}' => 'Exportiere Seite {number}',
+  'Failed to cleanup SVN working copy.' => 'Entsperren der Arbeitskopie fehlgeschlagen',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'SVN Plugin konnte nicht geladen werden,
+haben Sie die Subversion Tools installiert?',
   'Failed to load plugin: {name}' => 'Plugin {name} konnte nicht aktiviert werden',
+  'Failed update working copy.' => 'Erneuern der Arbeitskopie fehlgeschlagen',
   'File browser' => 'Dateibrowser',
   'File is not a text file: {file}' => 'Datei {file} ist keine Textdatei',
   'Filter' => 'Filter',
@@ -117,7 +184,7 @@ Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
   'Find what' => 'Suche was',
   'Follow new link' => 'Folge neuem Link',
   'For_mat|' => 'For_matierung|Formatierung',
-  'Format' => 'Formatierung',
+  'Format' => 'Format',
   'General' => 'Allgemein',
   'Go to "{link}"' => 'Gehe zu "{link}"',
   'H_idden|.' => 'V_ersteckt|Versteckt',
@@ -134,7 +201,10 @@ Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
   'Height' => 'Höhe',
   'Home Page' => 'Startseite',
   'Icon' => 'Symbol',
+  'Id' => 'Id',
+  'Include all open checkboxes' => 'Alle offenen Ankreuzfelder einschließen',
   'Index page' => 'Indexseite',
+  'Initial version' => 'Startversion',
   'Insert Date' => 'Datum einfügen',
   'Insert Image' => 'Bild einfügen',
   'Insert Link' => 'Link einfügen',
@@ -147,12 +217,15 @@ Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
   'Links to' => 'Verweist auf',
   'Match c_ase' => '_Groß- und Kleinschreibung beachten',
   'Media' => 'Medien',
+  'Modification Date' => 'Änderungsdatum',
   'Name' => 'Name',
   'New notebook' => 'Neues Notizbuch',
   'New page' => 'Neue Seite anlegen',
   'No such directory: {name}' => 'Verzeichnis {name} existiert nicht',
+  'No such file or directory: {name}' => 'Datei oder Verzeichnis {name} nicht gefunden',
   'No such file: {file}' => 'Datei {file} existiert nicht',
-  'No such notebook: {name}' => 'Verzeichnis {name} existiert nicht',
+  'No such notebook: {name}' => 'Notizbuch {name} existiert nicht',
+  'No such page: {page}' => 'Seite existiert nicht: {page}',
   'No such plugin: {name}' => 'Plugin {name} existiert nicht',
   'Normal' => 'Standard',
   'Not Now' => 'Jetzt nicht',
@@ -176,14 +249,21 @@ neue, leere Seite erzeugt',
   'Page Editable|Page editable' => 'Seite editierbar|Seite editierbar',
   'Page name' => 'Seitenname',
   'Pages' => 'Seiten',
-  'Please enter a name to save' => 'Dateiname zum Speichern eingeben',
+  'Password' => 'Passwort',
+  'Please enter a comment for this version' => 'Bitte geben Sie eine Beschreibung für diese Fassung ein',
+  'Please enter a name to save a copy of page: {page}' => 'Bitte geben Sie einen Namen ein, um eine Kopie der Seite {page} zu speichern.',
   'Please enter a {app_type}' => 'Bitte geben Sie ein: {app_type}',
+  'Please give a page first' => 'Bitte zuerst eine Seite angeben',
   'Please give at least a directory to store your pages.
 For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Bitte mindestens ein Verzeichnis zum Abspeichern von Seiten angeben.
 Für ein neues Notizbuch sollte dies ein leeres Verzeichnis sein.
 Zum Beispiel ein Verzeichnis "Notizen" im Persönlichen Ordner.',
-  'Please select a default notebook here' => 'Bitte wählen Sie hier ein Standardnotizbuch',
+  'Please provide the password for
+{path}' => 'Bitte geben Sie das Passwort für
+{path} ein',
+  'Please select a notebook first' => 'Bitte wählen Sie zuerst ein Notizbuch aus',
+  'Please select a version first' => 'Bitte zuerst eine Fassung wählen',
   'Plugin already loaded: {name}' => 'Plugin {name} ist schon aktiv',
   'Plugins' => 'Plugins',
   'Pr_eferences|Preferences dialog' => '_Einstellungen|Einstellungen',
@@ -200,20 +280,23 @@ Zum Beispiel ein Verzeichnis "Notizen" im Persönlichen Ordner.',
   'Rename to' => 'Umbenennen in',
   'Replace _all' => '_Alles ersetzen',
   'Replace with' => 'Ersetzen durch',
-  'S_ave A Copy...|Save a copy' => 'Speichern _unter|Kopie speichern',
+  'SVN cleanup|Cleanup SVN working copy' => 'SVN cleanup|SVN Arbeitskopie entsperren',
+  'SVN commit|Commit notebook to SVN repository' => 'SVN commit|Notizbuch ins SVN Archive einchecken',
+  'SVN update|Update notebook from SVN repository' => 'SVN update|Notizbuch aus dem SVN Archiv erneuern',
+  'S_ave Version...|Save Version' => 'Fassung S_peichern|Fassung Speichern',
   'Save Copy' => 'Speichern unter',
+  'Save version' => 'Fassung speichern',
   'Scanning tree ...' => 'Durchsuche Baum...',
   'Search' => 'Suche',
   'Search _Backlinks...|Search Back links' => 'Suche nach _Backlinks...|Suche nach Backlinks...',
   'Select File' => 'Datei auswählen',
   'Select Folder' => 'Ordner auswählen',
   'Send To...' => 'Senden an …',
-  'Set _Default' => 'Als Stan_dard öffnen',
-  'Set default notebook' => 'Setze Standardnotizbuch',
   'Show cursor for read-only' => 'Zeige Cursor bei schreibgeschützten Seiten',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Zeige den Cursor, auch wenn die Seite schreibgeschützt ist. Das ist nützlich, wenn Sie sich mit Hilfe der Tastatur durch die Seiten bewegen',
   'Slow file system' => 'Langsames Dateisystem',
   'Source' => 'Quelle',
+  'Source Format' => 'Quellformat',
   'Start the side pane with the whole tree expanded.' => 'Zeige expandierten Seitenbaum in der Seitenleiste',
   'Stri_ke|Strike' => '_Durchgestrichen|Durchgestrichen',
   'Strike' => 'Durchgestrichen',
@@ -222,7 +305,7 @@ Zum Beispiel ein Verzeichnis "Notizen" im Persönlichen Ordner.',
   'Tearoff menus' => 'Abreißbare Menüs',
   'Template' => 'Vorlage',
   'Text' => 'Text',
-  'Text Editor' => 'Text Editor',
+  'Text Editor' => 'Texteditor',
   'Text _From File...|Insert text from file' => 'Text aus Datei ein_fügen...|Text aus einer Datei einfügen',
   'Text editor' => 'Text Editor',
   'The equation failed to compile. Do you want to save anyway?' => 'Die Formel war fehlerhaft. Trotzdem speichern?',
@@ -236,7 +319,12 @@ bearbeitet werden.',
 404',
   'This page does not have a document folder' => 'Diese Seite gehört zu keinem Dokumentverzeichnis',
   'This page does not have a source' => 'Diese Seite hat keine Quelle',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => 'Diese Seite wurde im SVN Archiv geändert.
+Bitte erneuern sie Ihre Arbeitskopie (Werkzeuge -> SVN update).',
   'To_day|Today' => '_Heute|Erzeuge eine neue Seite für heute',
+  'Toggle Checkbox \'V\'|Toggle checkbox' => 'Ankreuzfeld \'V\' umschalten|Ankreuzfeld umschalten',
+  'Toggle Checkbox \'X\'|Toggle checkbox' => 'Ankreuzfeld \'X\' umschalten|Ankreuzfeld umschalten',
   'Underline' => 'Unterstrichen',
   'Updating links' => 'Links anpassen',
   'Updating links in {name}' => 'Passe Links in {name} an',
@@ -249,8 +337,11 @@ bearbeitet werden.',
   'Use the "Backspace" key to un-indent bullet lists (Same as "Shift-Tab")' => '\'Zurück(Backspace)\'-Taste verkleinert Einzug von unsortierten Listen (oder \'Hochstell-Tabulator\')',
   'Use the "Ctrl-Space" key combo to switch focus between text and side pane. If disabled you can still use "Alt-Space".' => '\'Strg-Leertaste\' wechselt den Fokus zwischen Textfenster und Seitenleiste. Sollte das abgestellt sein, benutzen Sie bitte \'Alt-Leertaste\'',
   'Use the "Enter" key to follow links. If disabled you still can use "Alt-Enter"' => '\'Eingabe\'-Taste folgt Links. Sollte das abgestellt sein, benutzen Sie bitte \'Alt-Eingabe\'',
+  'User' => 'Benutzer',
   'User name' => 'Benutzername',
   'Verbatim' => 'Vorformatiert',
+  'Versions' => 'Versionen',
+  'View _Annotated...' => 'Ansicht mit _Anmerkungen',
   'View _Log' => '_Protokoll anzeigen',
   'Web browser' => 'Web-Browser',
   'Whole _word' => 'Ganzes _Wort',
@@ -258,6 +349,9 @@ bearbeitet werden.',
   'Word Count' => 'Wortanzahl',
   'Words' => 'Worte',
   'You can add rules to your search query below' => 'Unten können Regeln zur Suchabfrage hinzugefügt werden',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => 'Sie können entweder das Versionskontrollsystem <b>Bazaar</b> oder <b>Subversion</b> verwenden.
+In der Hilfe finden Sie sie Systemanforderungen.',
   'You have no {app_type} configured' => 'Es wurde kein {app_type} konfiguriert',
   'You need to restart the application
 for plugin changes to take effect.' => 'Sie müssen Zim neustarten, damit Änderungen
@@ -273,11 +367,13 @@ der Plugin-Einstellungen wirksam werden',
   '_Child|Go to child page' => '_Untergeordnet|Gehe zur untergeordneten Seite',
   '_Close|Close window' => '_Schließen|Fenster schließen',
   '_Contents|Help contents' => '_Inhalt|Inhalt der Hilfe',
+  '_Copy Page...|Copy page' => '_Kopiere Seite...|Kopiere Seite',
   '_Copy|Copy' => '_Kopieren|Kopieren',
   '_Date and Time...|Insert date' => '_Datum und Zeit...|Datum und Uhrzeit einfügen',
   '_Delete Page|Delete page' => '_Löschen|Lösche Seite',
   '_Delete|Delete' => '_Löschen|Löschen',
   '_Discard changes' => 'Änderungen _verwerfen',
+  '_Edit' => 'B_earbeiten',
   '_Edit Equation' => 'Formel b_earbeiten',
   '_Edit Link' => 'Bearbeite Link',
   '_Edit Link...|Edit link' => 'Link _bearbeiten|Link bearbeiten',
@@ -307,10 +403,12 @@ der Plugin-Einstellungen wirksam werden',
   '_Next' => '_Nächstes',
   '_Next in index|Go to next page' => '_Nächste Seite im Index|Gehe zur nächsten Seite im Index',
   '_Normal|Normal' => '_Normal|Normal',
+  '_Notebook Changes...' => 'Änderungsprotokoll _Notizbuch',
   '_Open Another Notebook...|Open notebook' => 'Öffne ein weiteres N_otizbuch...|Öffne Notizbuch',
   '_Open link' => 'Öffne _Link',
   '_Overwrite' => '_Überschreiben',
   '_Page' => '_Seite',
+  '_Page Changes...' => '_Änderungen an der Seite...',
   '_Parent|Go to parent page' => '_Übergeordnet|Gehe zur übergeordneten Seite',
   '_Paste|Paste' => '_Einfügen|Einfügen',
   '_Preview' => '_Vorschau',
@@ -326,6 +424,7 @@ der Plugin-Einstellungen wirksam werden',
   '_Replace' => '_Ersetzen',
   '_Replace...|Find and Replace' => '_Ersetzen|Suchen und Ersetzen',
   '_Reset' => '_Zurücksetzen',
+  '_Restore Version...' => 'Ve_rsion wiederherstellen...',
   '_Save Copy' => '_Speichern unter',
   '_Save a copy...' => '_Speichern unter',
   '_Save|Save page' => '_Speichern|Seite speichern',
@@ -341,17 +440,22 @@ der Plugin-Einstellungen wirksam werden',
   '_Underline|Underline' => '_Unterstrichen|Unterstrichen',
   '_Undo|Undo' => '_Rückgängig|Rückgängig',
   '_Update links in this page' => '_Links in dieser Seite anpassen',
-  '_Update {number} pages linking here' => '_Anpassen von {number} Seiten, die hierher verweisen',
+  '_Update {number} page linking here' => [
+    '{number} Link auf diese Seite akt_ualisieren',
+    '{number} Links auf diese Seite akt_ualisieren'
+  ],
   '_Verbatim|Verbatim' => '_Vorformatiert|Vorformatiert',
+  '_Versions...|Versions' => '_Fassungen...|Fassungen',
   '_View|' => '_Ansicht|Ansicht',
   '_Word Count|Word count' => '_Worte zählen|Worte zählen',
   'other...' => 'andere...',
-  'translator-credits' => 'Launchpad Contributions:
-  Jaap Karssenberg https://launchpad.net/~pardus-cpan
-  Klaus Vormweg https://launchpad.net/~klaus-vormweg
-  Matthias Mailänder https://launchpad.net/~mailaender
-  René \'Necoro\' Neumann https://launchpad.net/~necoro',
   '{name}_(Copy)' => '{name}_(Kopie)',
-  '{number} _Back links' => '{number} _Backlinks',
-  '{total} items total' => 'insgesamt {total} Einträge'
+  '{number} _Back link' => [
+    '{number} Rückverweis',
+    '{number} Rückverweise'
+  ],
+  '{number} item total' => [
+    'insgesamt {number} Eintrag',
+    'insgesamt {number} Einträge'
+  ]
 };
