@@ -10,14 +10,14 @@
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: pardus@cpan.org
 # POT-Creation-Date: 2008-10-27 21:09+0100
-# PO-Revision-Date: 2008-11-07 22:17+0000
+# PO-Revision-Date: 2009-02-07 21:04+0000
 # Last-Translator: Juhana Uuttu <Unknown>
 # Language-Team: Finnish <fi@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-11-09 09:05+0000
+# X-Launchpad-Export-Date: 2009-02-17 18:56+0000
 # X-Generator: Launchpad (build Unknown)
 # X-Poedit-Country: FINLAND
 # X-Poedit-Language: Finnish
@@ -113,11 +113,11 @@ Haluatko päivittää muistivihkoosi käyttämään uutta pohjaa?
   'Can not save a version without comment' => 'En pysty tallentamaan versiota ilman kommenttia',
   'Can not save to page: {name}' => 'En pysty tallentamaan sivulle: {name}',
   'Can\'t find {url}' => 'En löydä {url}',
-  'Cha_nge' => '_Vaihda',
+  'Cha_nge' => 'M_uuta',
   'Chars' => 'Kirjaimia',
   'Check _spelling|Spell check' => 'Oikolue|Oikoluku',
-  'Check checkbox lists recursive' => '',
-  'Checking a checkbox list item will also check any sub-items' => '',
+  'Check checkbox lists recursive' => 'Vaihda rastiruutulista rekursiivisesti',
+  'Checking a checkbox list item will also check any sub-items' => 'Rastiruudun muokkaus muuttaa myös sen alla olevat rastit',
   'Choose {app_type}' => 'Valitse {app_type}',
   'Co_mpare Page...' => 'Vertaa sivu...',
   'Command' => 'Komento',
@@ -143,7 +143,7 @@ Haluatko päivittää muistivihkoosi käyttämään uutta pohjaa?
   'Current' => 'Nykyinen',
   'Customise' => 'Muokkaa',
   'Date' => 'Päivämäärä',
-  'Default notebook' => 'Vakiomuistivihko',
+  'Default notebook' => 'Vakiovihko',
   'Details' => 'Yksityiskohdat',
   'Diff Editor' => 'Diff-editori',
   'Diff editor' => 'Diff-editori',
@@ -166,12 +166,12 @@ Haluatko päivittää muistivihkoosi käyttämään uutta pohjaa?
   'Expand side pane' => 'Avaa sivupaneeli',
   'Export page' => 'Vie sivu',
   'Exporting page {number}' => 'Viedään sivua {number}',
-  'Failed to cleanup SVN working copy.' => '',
+  'Failed to cleanup SVN working copy.' => 'En onnistunut siivoamaan SVN-työkopiota.',
   'Failed to load SVN plugin,
 do you have subversion utils installed?' => 'SVN-lisäosan lataus epäonnistui.
 Onko sinulla subversion-työkalut asennettuna?',
   'Failed to load plugin: {name}' => 'Lisäosan lataus epäonnistui: {name}',
-  'Failed update working copy.' => '',
+  'Failed update working copy.' => 'Kopion päivitys epäonnistui.',
   'File browser' => 'Tiedostoselain',
   'File is not a text file: {file}' => 'Tiedosto ei sisällä tekstiä: {file}',
   'Filter' => 'Suodatin',
@@ -200,7 +200,7 @@ Onko sinulla subversion-työkalut asennettuna?',
   'Home Page' => 'Kotisivu',
   'Icon' => 'Ikoni',
   'Id' => 'Id',
-  'Include all open checkboxes' => '',
+  'Include all open checkboxes' => 'Lisää mukaan kaikki avoimet valintaruudut',
   'Index page' => 'Indeksisivu',
   'Initial version' => 'Ensiversio',
   'Insert Date' => 'Lisää päivämäärä',
@@ -220,7 +220,7 @@ Onko sinulla subversion-työkalut asennettuna?',
   'New notebook' => 'Uusi muistivihko',
   'New page' => 'Uusi sivu',
   'No such directory: {name}' => 'Hakemisto ei olemassa: {name}',
-  'No such file or directory: {name}' => '',
+  'No such file or directory: {name}' => 'Tiedosto/hakemisto ei olemassa: {name}',
   'No such file: {file}' => 'Tiedosto ei olemassa: {file}',
   'No such notebook: {name}' => 'Vihko ei olemassa: {name}',
   'No such page: {page}' => 'Sivu ei olemassa: {page}',
@@ -257,7 +257,8 @@ For example a "Notes" directory in your home dir.' => 'Anna vähintään yksi ha
 Uudelle muistivihkolle sen pitäisi olla tyhjä hakemisto.
 Esimerkiksi "Ruokareseptit"-kansio kotihakemistossasi.',
   'Please provide the password for
-{path}' => '',
+{path}' => 'Anna salasana hakemistolle:
+{path}',
   'Please select a notebook first' => 'Valitse muistivihko ensin',
   'Please select a version first' => 'Valitse versio ensiksi',
   'Plugin already loaded: {name}' => 'Lisäosa jo ladattu: {name}',
@@ -276,9 +277,9 @@ Esimerkiksi "Ruokareseptit"-kansio kotihakemistossasi.',
   'Rename to' => 'Nimeä muotoon',
   'Replace _all' => 'Korvaa ka_ikki',
   'Replace with' => 'Korvaa',
-  'SVN cleanup|Cleanup SVN working copy' => '',
-  'SVN commit|Commit notebook to SVN repository' => '',
-  'SVN update|Update notebook from SVN repository' => '',
+  'SVN cleanup|Cleanup SVN working copy' => 'SVN siivous|Siivoa SVN-työkopio',
+  'SVN commit|Commit notebook to SVN repository' => 'SVN-merkintä|Merkitse vihko SVN-varastoon',
+  'SVN update|Update notebook from SVN repository' => 'SVN-päivitys|Päivitä vihko SVN-varastosta',
   'S_ave Version...|Save Version' => 'Tallenna ve_rsio...|Tallenna versio',
   'Save Copy' => 'Tallenna kopio',
   'Save version' => 'Tallenna versio',
@@ -315,10 +316,11 @@ puuttuu. Ei voi muokata yhtälöä.',
   'This page does not have a document folder' => 'Tällä sivulla ei ole asiakirjakansiota',
   'This page does not have a source' => 'Tällä sivulla ei ole lähdettä',
   'This page was updated in the repository.
-Please update your working copy (Tools -> SVN update).' => '',
+Please update your working copy (Tools -> SVN update).' => 'Tästä sivusta on päivitys varastossa.
+Ole hyvä ja päivitä kopiosi (Työkalut -> SVN päivitys).',
   'To_day|Today' => 'Tänään|Tänään',
-  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
-  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => 'Vaihda rastiruutuun \'V\'|Vaihda rasti',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => 'Vaihda rastiruutuun \'X\'|Vaihda rasti',
   'Underline' => 'Alleviivaus',
   'Updating links' => 'Päivitetään linkit',
   'Updating links in {name}' => 'Päivitetään linkit kohteesta {name}',
