@@ -1,17 +1,32 @@
+# Galician translation for zim
+# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
+# This file is distributed under the same license as the zim package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
+# 
+# 
+# TRANSLATORS:
+# Roberto Suarez (gl)
+# marisma (gl)
+# 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-05-08 00:12+0800
-# PO-Revision-Date: 2008-05-15 17:15+0000
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2008-08-28 16:49+0000
 # Last-Translator: Roberto Suarez <robe@allenta.com>
 # Language-Team: Galician <gl@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
-# X-Launchpad-Export-Date: 2008-05-19 15:32+0000
+# Plural-Forms: nplurals=2; plural=n != 1;
+# X-Launchpad-Export-Date: 2008-11-09 09:04+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
 
+# Subroutine to determine plural:
+sub {my $n = shift; $n != 1},
+
+# Hash with translation strings:
 {
   '%a %b %e %Y' => '%a %b %e %Y',
   '<b>Delete page</b>
@@ -21,6 +36,10 @@ page \'{name}\' ?' => '<b>Borrar páxina</b>
 
 ¿Está seguro de querer borrar
 a páxina \'{name}\'?',
+  '<b>Enable Version Control</b>
+
+Version control is currently not enabled for this notebook.
+Do you want to enable it ?' => '<b>Activar o Control de Versións</b>',
   '<b>Folder does not exist.</b>
 
 The folder: {path}
@@ -37,6 +56,12 @@ Do you want to overwrite it?' => '<b>A páxina xa existe</b>
 A páxina \'{name}\'
 xa existe.
 ¿Desexa escribir por encima?',
+  '<b>Restore page to saved version?</b>
+
+Do you want to restore page: {page}
+to saved version: {version} ?
+
+All changes since the last saved version will be lost !' => '',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -53,6 +78,7 @@ espacios por mes.
 ¿Desexa actualizar este caderno ó novo esquema?
 ',
   'Add \'tearoff\' strips to the menus' => 'Engadir barras para desprender os menúes',
+  'Application show two text files side by side' => 'Aplicación para amosar dous ficheiros de texto simultaneamente',
   'Application to compose email' => 'Aplicación de correo electrónico',
   'Application to edit text files' => 'Aplicación para editar ficheiros de texto',
   'Application to open directories' => 'Aplicación para abrir directorios',
@@ -60,33 +86,57 @@ espacios por mes.
   'Attach _File|Attach external file' => 'Anexar _ficheiro|Anexar un ficheiro externo',
   'Attach external files' => 'Adxuntar ficheiros externos',
   'Auto-format entities' => 'Formato automático de entidades',
+  'Auto-increment numbered lists' => 'Incrementar automáticamente as listas enumeradas',
   'Auto-link CamelCase' => 'Auto-ligar CamelCase',
   'Auto-link files' => 'Auto-ligar ficheiros',
+  'Auto-save version on close' => 'Gardar versión automáticamente ó saír',
   'Auto-select words' => 'Seleccionar palabras automáticamente',
+  'Automatically increment items in a numbered list' => 'Incrementar automáticamente os artigos nunha lista enumerada',
   'Automatically link file names when you type' => 'Ligar ficheiros automáticamente cando se escriben',
   'Automaticly link CamelCase words when you type' => 'Ligar automáticamente as palabras en CamelCase cando se escriben',
   'Automaticly select the current word when you toggle the format' => 'Seleccionar automáticamente a palabra actual cando cambia o formato',
   'Bold' => 'Negriña',
   'Calen_dar|Show calendar' => 'Calen_dario|Amosar calendario',
   'Calendar' => 'Calendario',
+  'Can not find application "bzr"' => '',
+  'Can not find application "{name}"' => '',
+  'Can not save a version without comment' => 'Non está permitido gardar unha versión sin comentario',
   'Can not save to page: {name}' => 'Non se puido gardar á páxina: {name}',
   'Can\'t find {url}' => 'Non se pode atopar {url}',
   'Cha_nge' => 'Ca_mbiar',
   'Chars' => 'Caracteres',
   'Check _spelling|Spell check' => 'Comprobar _ortografía|Comprobación da ortografía',
+  'Check checkbox lists recursive' => '',
+  'Checking a checkbox list item will also check any sub-items' => '',
   'Choose {app_type}' => 'Escolla {app_type}',
+  'Co_mpare Page...' => 'Co_mparar Páxina...',
   'Command' => 'Comando',
+  'Comment' => '',
+  'Compare this version with' => 'Comparar esta versión con',
   'Copy Email Address' => 'Copiar Enderezo de Correo-e',
   'Copy Location|Copy location' => 'Copiar ubicación|Copiar ubicación',
   'Copy _Link' => 'Copiar _Ligazón',
   'Could not delete page: {name}' => 'Non foi posible borrar a páxina: {name}',
+  'Could not get annotated source for page {page}' => 'Non foi posible recuperar a fonte anotada para a páxina {page}',
+  'Could not get changes for page: {page}' => 'Non foi posible recuperar os cambios para a páxina: {page}',
+  'Could not get changes for this notebook' => '',
+  'Could not get file for page: {page}' => 'Non foi posible recuperar o ficheiro para a páxina: {page}',
+  'Could not get versions to compare' => 'Non foi posible recuperar as versións para comparar',
+  'Could not initialize version control' => 'Non foi posible inicializar o sistema de control de versións',
   'Could not load page: {name}' => 'Non se puido cargar a páxina: {name}',
   'Could not rename {from} to {to}' => 'Non foi posible cambiar o nome de {from} a {to}',
   'Could not save page' => 'Non foi posible gardar a páxina',
+  'Could not save version' => 'Non foi posible gardar a versión',
   'Creating a new link directly opens the page' => 'Crear unha nova ligazón abre directamente a páxina',
+  'Creation Date' => 'Data de Creación',
   'Cu_t|Cut' => '_Cortar|Cortar',
+  'Current' => 'Actual',
   'Customise' => 'Personalizar',
   'Date' => 'Data',
+  'Default notebook' => 'Caderno por defecto',
+  'Details' => 'Detalles',
+  'Diff Editor' => 'Editor de diferencias',
+  'Diff editor' => 'Editor de diferencias',
   'Directory' => 'Directorio',
   'Document Root' => 'Raíz dos documentos',
   'E_quation...|Insert equation' => 'E_cuación...|Inserir ecuación',
@@ -106,7 +156,11 @@ espacios por mes.
   'Expand side pane' => 'Expandir panel lateral',
   'Export page' => 'Exportar páxina',
   'Exporting page {number}' => 'Exportando páxina {number}',
+  'Failed to cleanup SVN working copy.' => '',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => '',
   'Failed to load plugin: {name}' => 'Fallou a carga do plugin: {name}',
+  'Failed update working copy.' => '',
   'File browser' => 'Navegador de ficheiros',
   'File is not a text file: {file}' => 'O ficheiro non é un ficheiro de texto: {file}',
   'Filter' => 'Filtrar',
@@ -134,7 +188,10 @@ espacios por mes.
   'Height' => 'Alto',
   'Home Page' => 'Páxina de inicio',
   'Icon' => 'Icono',
+  'Id' => 'Id',
+  'Include all open checkboxes' => '',
   'Index page' => 'Páxina de Índice',
+  'Initial version' => 'Versión inicial',
   'Insert Date' => 'Inserir data',
   'Insert Image' => 'Inserir unha Imaxe',
   'Insert Link' => 'Inserir unha ligazón',
@@ -147,12 +204,15 @@ espacios por mes.
   'Links to' => 'Ligazóns con',
   'Match c_ase' => '_Distinguir maiúsculas e minúsculas',
   'Media' => 'Medio',
+  'Modification Date' => 'Data de Modificación',
   'Name' => 'Nome',
   'New notebook' => 'Novo caderno',
   'New page' => 'Nova páxina',
   'No such directory: {name}' => 'Non hai tal directorio: {name}',
+  'No such file or directory: {name}' => '',
   'No such file: {file}' => 'Non hai tal ficheiro: {file}',
   'No such notebook: {name}' => 'Non hai tal caderno: {name}',
+  'No such page: {page}' => 'Non existe tal páxina: {page}',
   'No such plugin: {name}' => 'Non hai tal plugin: {name}',
   'Normal' => 'Normal',
   'Not Now' => 'Agora non',
@@ -175,8 +235,11 @@ crea unha nova páxina.',
   'Page Editable|Page editable' => 'Páxina editable|Páxina editable',
   'Page name' => 'Nome da páxina',
   'Pages' => 'Páxinas',
-  'Please enter a name to save' => 'Por favor, introduza un nome para a copia',
+  'Password' => '',
+  'Please enter a comment for this version' => 'Por favor, introduza un comentario para esta versión',
+  'Please enter a name to save a copy of page: {page}' => 'Por favor, introduza un nome para gardar a copia da páxina: {page}',
   'Please enter a {app_type}' => 'Por favor, introduza un {app_type}',
+  'Please give a page first' => 'Por favor, introduza unha páxina primeiro',
   'Please give at least a directory to store your pages.
 For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Por favor, indique como mínimo un directorio
@@ -184,7 +247,10 @@ onde gardar as súas páxinas. Para un novo caderno
 isto debería ser un directorio baleiro. Por exemplo,
 un directorio chamado "Notas" no seu directorio
 de inicio.',
-  'Please select a default notebook here' => 'Por favor, escolla un caderno por defecto aquí',
+  'Please provide the password for
+{path}' => '',
+  'Please select a notebook first' => 'Por favor, seleccione un caderno primeiro',
+  'Please select a version first' => 'Seleccione unha versión primeiro',
   'Plugin already loaded: {name}' => 'Plugin xa cargado: {name}',
   'Plugins' => 'Extensións',
   'Pr_eferences|Preferences dialog' => 'Pre_ferencias|Preferencias',
@@ -201,21 +267,24 @@ de inicio.',
   'Rename to' => 'Renomear como',
   'Replace _all' => 'Substituír _todo',
   'Replace with' => 'Substituír por',
-  'S_ave A Copy...|Save a copy' => 'G_ardar unha copia...|Gardar unha copia',
+  'SVN cleanup|Cleanup SVN working copy' => '',
+  'SVN commit|Commit notebook to SVN repository' => '',
+  'SVN update|Update notebook from SVN repository' => '',
+  'S_ave Version...|Save Version' => '_Gardar Versión...|Gardar Versión',
   'Save Copy' => 'Gardar copia',
+  'Save version' => 'Gardar versión',
   'Scanning tree ...' => 'Buscando na árbore...',
   'Search' => 'Procurar',
   'Search _Backlinks...|Search Back links' => 'Buscar ligazón_s de inversas...|Buscar ligazóns inversas',
   'Select File' => 'Escoller Ficheiro',
   'Select Folder' => 'Seleccionar Cartafol',
   'Send To...' => 'Enviar a...',
-  'Set _Default' => 'Usar por _defecto',
-  'Set default notebook' => 'Usar como caderno por defecto',
   'Show cursor for read-only' => 'Amosar o cursor en modo de só lectura',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Amosar o cursor aínda que non se poda editar a páxina.
 Esto é útil para navegar usando o teclado.',
   'Slow file system' => 'Sistema de ficheiros lento',
   'Source' => 'Orixe',
+  'Source Format' => 'Formato orixinal',
   'Start the side pane with the whole tree expanded.' => 'Comezar coa árbore do panel lateral expandida',
   'Stri_ke|Strike' => '_Tachado|Tachado',
   'Strike' => 'Tachado',
@@ -237,7 +306,11 @@ non existe. Non se pode editar a ecuación.',
 404',
   'This page does not have a document folder' => 'Esta páxina non ten unha carpeta de documentos',
   'This page does not have a source' => 'Esta páxina non ten fonte',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => '',
   'To_day|Today' => '_Hoxe|Hoxe',
+  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
+  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
   'Underline' => 'Subliñado',
   'Updating links' => 'Actualizando enlaces',
   'Updating links in {name}' => 'Actualizando enlaces en {name}',
@@ -253,8 +326,11 @@ a sangría dos elementos de listas de puntos (o mesmo que "Shift-Tab")',
 Se non se activa esta opción, sempre pode usar "Alt-Espacio".',
   'Use the "Enter" key to follow links. If disabled you still can use "Alt-Enter"' => 'Use a tecla "Enter" para seguir ligazóns. Se non se activa esta opción,
 sempre pode usar "Alt-Enter".',
+  'User' => 'Usuario',
   'User name' => 'Nome de usuario',
   'Verbatim' => 'Verbatim',
+  'Versions' => 'Versións',
+  'View _Annotated...' => 'Ver _Anotacións...',
   'View _Log' => 'Ver _rexistro',
   'Web browser' => 'Navegador web',
   'Whole _word' => 'Palabras _enteiras',
@@ -262,6 +338,8 @@ sempre pode usar "Alt-Enter".',
   'Word Count' => 'Cantidade de palabras',
   'Words' => 'Palabras',
   'You can add rules to your search query below' => 'Pode engadir regras para a súa consulta abaixo',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => '',
   'You have no {app_type} configured' => 'Non ten un {app_type} configurado',
   'You need to restart the application
 for plugin changes to take effect.' => 'Necesita reiniciar a aplicación
@@ -278,11 +356,13 @@ fagan efecto.',
   '_Child|Go to child page' => '_Descender|Ir á páxina inferior',
   '_Close|Close window' => 'Pe_char|Pechar ventá',
   '_Contents|Help contents' => '_Contidos|Contidos da axuda',
+  '_Copy Page...|Copy page' => '_Copiar Páxina...|Copiar páxina',
   '_Copy|Copy' => '_Copiar|Copiar',
   '_Date and Time...|Insert date' => '_Data e hora...|Inserir data',
   '_Delete Page|Delete page' => 'E_liminar páxina|Eliminar páxina',
   '_Delete|Delete' => '_Borrar|Borrar',
   '_Discard changes' => '_Descartar cambios',
+  '_Edit' => '',
   '_Edit Equation' => '_Editar Ecuación',
   '_Edit Link' => '_Editar ligazón',
   '_Edit Link...|Edit link' => '_Editar ligazón...|Editar ligazón',
@@ -312,10 +392,12 @@ fagan efecto.',
   '_Next' => '_Seguinte',
   '_Next in index|Go to next page' => '_Vindeira no índice|Ir á vindeira páxina',
   '_Normal|Normal' => '_Normal|Normal',
+  '_Notebook Changes...' => 'Cambios no _caderno ...',
   '_Open Another Notebook...|Open notebook' => 'Abrir _outro caderno...|Abrir caderno',
   '_Open link' => 'Abrir _ligazón',
   '_Overwrite' => 'S_obrescribir',
   '_Page' => '_Páxina',
+  '_Page Changes...' => 'Cambios na _páxina',
   '_Parent|Go to parent page' => '_Subir|Ir á páxina superior',
   '_Paste|Paste' => '_Pegar|Pegar',
   '_Preview' => 'Vista _previa',
@@ -331,6 +413,7 @@ fagan efecto.',
   '_Replace' => '_Substituír',
   '_Replace...|Find and Replace' => '_Substituir...|Procurar e substituir',
   '_Reset' => '_Restablecer',
+  '_Restore Version...' => '_Restaurar Versión...',
   '_Save Copy' => '_Gardar copia',
   '_Save a copy...' => '_Gardar unha copia...',
   '_Save|Save page' => '_Gardar|Gardar páxina',
@@ -346,14 +429,22 @@ fagan efecto.',
   '_Underline|Underline' => '_Subliñado|Subliñado',
   '_Undo|Undo' => '_Desfacer|Desfacer',
   '_Update links in this page' => 'Actualizar _enlaces nesta páxina',
-  '_Update {number} pages linking here' => '_Actualizar {number} páxinas que enlazan aquí',
+  '_Update {number} page linking here' => [
+    '_Actualizar {number} páxina que liga aquí',
+    '_Actualizar {number} páxinas que ligan aquí'
+  ],
   '_Verbatim|Verbatim' => '_Verbatim|Verbatim',
+  '_Versions...|Versions' => '_Versións...|Versións',
   '_View|' => '_Ver|',
   '_Word Count|Word count' => '_Contar palabras|Contar palabras',
   'other...' => 'Outro...',
-  'translator-credits' => 'Launchpad Contributions:
-  Roberto Suarez https://launchpad.net/~robe-allenta',
   '{name}_(Copy)' => '{name}_(Copia)',
-  '{number} _Back links' => '{number} ligazóns inversas',
-  '{total} items total' => '{total} elementos en total'
+  '{number} _Back link' => [
+    '{number} ligazón _inversa',
+    '{number} ligazóns _inversas'
+  ],
+  '{number} item total' => [
+    '{number} artigo en total',
+    '{number} artigos en total'
+  ]
 };
