@@ -7,20 +7,21 @@
 # TRANSLATORS:
 # Aron Xu (zh_CN)
 # Cheese Lee (zh_CN)
+# Junnan Wu (zh_CN)
 # rainofchaos (zh_CN)
 # 太和 (zh_CN)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
 # POT-Creation-Date: 2008-10-27 21:09+0100
-# PO-Revision-Date: 2008-11-09 15:35+0000
-# Last-Translator: Cheese Lee <Unknown>
+# PO-Revision-Date: 2008-12-20 05:51+0000
+# Last-Translator: Junnan Wu <Unknown>
 # Language-Team: Simplified Chinese <zh_CN@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=1; plural=0;
-# X-Launchpad-Export-Date: 2008-11-12 17:32+0000
+# X-Launchpad-Export-Date: 2009-02-17 18:56+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -115,12 +116,12 @@ Do you want to upgrade this notebook to the new layout?
   'Cha_nge' => '更改(_N)',
   'Chars' => '字符',
   'Check _spelling|Spell check' => '拼写检查(_S)|拼写检查',
-  'Check checkbox lists recursive' => '',
-  'Checking a checkbox list item will also check any sub-items' => '',
+  'Check checkbox lists recursive' => '递归选中复选框序列',
+  'Checking a checkbox list item will also check any sub-items' => '选中一个复选框时自动选中其子项',
   'Choose {app_type}' => '选择 {app_type}',
   'Co_mpare Page...' => '对比页面(_M)...',
   'Command' => '命令',
-  'Comment' => '',
+  'Comment' => '备注',
   'Compare this version with' => '对比版本：',
   'Copy Email Address' => '复制电子邮件地址',
   'Copy Location|Copy location' => '复制地址|复制地址',
@@ -165,11 +166,11 @@ Do you want to upgrade this notebook to the new layout?
   'Expand side pane' => '扩展侧边栏',
   'Export page' => '导出页面',
   'Exporting page {number}' => '导出页面 {number}',
-  'Failed to cleanup SVN working copy.' => '',
+  'Failed to cleanup SVN working copy.' => '清除临时文件失败',
   'Failed to load SVN plugin,
-do you have subversion utils installed?' => '',
+do you have subversion utils installed?' => '无法加载SVN插件，确认安装subversion工具了吗？',
   'Failed to load plugin: {name}' => '没有加载成功的插件:{name}',
-  'Failed update working copy.' => '',
+  'Failed update working copy.' => '清除临时文件失败',
   'File browser' => '文件浏览器',
   'File is not a text file: {file}' => '不是文本文件: {file}',
   'Filter' => '过滤器',
@@ -198,7 +199,7 @@ do you have subversion utils installed?' => '',
   'Home Page' => '主页',
   'Icon' => '图标',
   'Id' => '编号',
-  'Include all open checkboxes' => '',
+  'Include all open checkboxes' => '加入所有打开的复选框',
   'Index page' => '索引页',
   'Initial version' => '初始版本',
   'Insert Date' => '插入日期',
@@ -246,7 +247,7 @@ also automatically creates a new page.' => '注意，如果链接到不存在的
   'Pages' => '页面',
   'Password' => '密码',
   'Please enter a comment for this version' => '请为此版本添加一个注释',
-  'Please enter a name to save a copy of page: {page}' => '请输入页面{page}的副本名称:',
+  'Please enter a name to save a copy of page: {page}' => '请输入页面 {page} 的副本名称:',
   'Please enter a {app_type}' => '请输入一个 {app_type}',
   'Please give a page first' => '请先提供页面',
   'Please give at least a directory to store your pages.
@@ -255,7 +256,7 @@ For example a "Notes" directory in your home dir.' => '请至少为您的页面
 对于新的记事本来说应该是空目录。
 例如在您的主目录中的 "记事本"目录。',
   'Please provide the password for
-{path}' => '',
+{path}' => '请输入{path}的密码',
   'Please select a notebook first' => '请先选择一个记事本',
   'Please select a version first' => '请先选择一个版本',
   'Plugin already loaded: {name}' => '已经加载的插件:{name}',
@@ -274,8 +275,8 @@ For example a "Notes" directory in your home dir.' => '请至少为您的页面
   'Rename to' => '重命名为',
   'Replace _all' => '全部替换(_A)',
   'Replace with' => '替换为',
-  'SVN cleanup|Cleanup SVN working copy' => '',
-  'SVN commit|Commit notebook to SVN repository' => '',
+  'SVN cleanup|Cleanup SVN working copy' => '清除SVN临时文件',
+  'SVN commit|Commit notebook to SVN repository' => '读取SVN库',
   'SVN update|Update notebook from SVN repository' => 'SVN 更新|从SVN库更新笔记本',
   'S_ave Version...|Save Version' => '保存版本(_A)...|保存版本',
   'Save Copy' => '保存副本',
@@ -313,10 +314,10 @@ is missing. Can not edit equation.' => '无法找到图像: {path}
   'This page does not have a document folder' => '此页面无文档文件夹',
   'This page does not have a source' => '此页面没有源代码',
   'This page was updated in the repository.
-Please update your working copy (Tools -> SVN update).' => '',
+Please update your working copy (Tools -> SVN update).' => '请对文件进行更新（工具>更新SVN）',
   'To_day|Today' => '今天(_D)|今天',
-  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
-  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => '选中复选框 \'V\'|切换复选框',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => '选中复选框 \'X\'|切换复选框',
   'Underline' => '下划线',
   'Updating links' => '更新链接',
   'Updating links in {name}' => '更新{name}中的链接',
@@ -342,7 +343,8 @@ Please update your working copy (Tools -> SVN update).' => '',
   'Words' => '字',
   'You can add rules to your search query below' => '可以为查询添加规则',
   'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
-Please click \'help\' to read about the system requirements.' => '',
+Please click \'help\' to read about the system requirements.' => '你可以选择使用<b>Bazaar</b>或者<b>Subversion</b>版本控制系统
+请点击“帮助”以了解系统要求',
   'You have no {app_type} configured' => '您没有配置 {app_type}',
   'You need to restart the application
 for plugin changes to take effect.' => '重启应用程序后
